@@ -12,9 +12,9 @@ cd /tmp
 mkdir -p build && cd build
 cmake \
   -DCMAKE_UNITY_BUILD=ON -DCMAKE_UNITY_BUILD_BATCH_SIZE=32 \
-  -DCMAKE_CXX_FLAGS="-Wall -Wextra -Werror -D_GLIBCXX_ASSERTIONS -DPERSALYS_APPIMAGE" \
-  -DSWIG_COMPILE_FLAGS="-Wno-error=unused-parameter" \
-  -DPYTHON_EXECUTABLE=/usr/local/bin/python3 \
+  -DCMAKE_CXX_FLAGS="-Wall -Wextra -Wpedantic -Wshadow -Werror -DPERSALYS_APPIMAGE" \
+  -DCMAKE_SWIG_FLAGS="-Werror" -DSWIG_COMPILE_FLAGS="-Wno-unused-parameter -Wno-shadow" \
+  -DPython_EXECUTABLE=/usr/local/bin/python3 \
   -DSPHINX_FLAGS="-W -T -j8" \
   -DCMAKE_INSTALL_PREFIX=/tmp/persalys.AppDir/usr -DCMAKE_INSTALL_LIBDIR=lib \
   -DOPENGL_opengl_LIBRARY=/usr/lib64/libGL.so \
@@ -23,7 +23,7 @@ make install
 make tests
 xvfb-run -s "-screen 0 1024x768x24" ctest --output-on-failure --timeout 30 -j8
 
-cd /tmp/persalys.AppDir/usr/share/persalys/doc/; zip -r /tmp/persalys-doc.zip ./html/*; cd -
+cd /tmp/persalys.AppDir/usr/share/doc/persalys/; zip -r /tmp/persalys-doc.zip ./html/*; cd -
 
 cd /tmp
 
@@ -33,9 +33,10 @@ cat > persalys.AppDir/AppRun <<\EOF
 #!/bin/sh
 HERE=$(dirname $(readlink -f "${0}"))
 export PATH=${HERE}/usr/bin/:${PATH}
-export LD_LIBRARY_PATH=${HERE}/usr/lib/:${HERE}/usr/lib/x86_64-linux-gnu/omc/
+export LD_LIBRARY_PATH=${HERE}/usr/lib/:${HERE}/usr/lib/omc/
 export PYTHONHOME=${HERE}/usr/
-export PYTHONPATH=
+export PYTHONUSERBASE=${HOME}/.persalys_base
+export PYTHONPATH=${PYTHONUSERBASE}/lib/python3.11/site-packages
 export QT_PLUGIN_PATH=${HERE}/usr/lib/plugins
 export PV_PLUGIN_PATH=${HERE}/usr/lib/paraview/plugins/BagPlotViewsAndFilters
 
@@ -76,6 +77,7 @@ cp -v /usr/lib64/libjpeg.so.62 persalys.AppDir/usr/lib
 cp -v /usr/lib64/libicu*.so.50 persalys.AppDir/usr/lib
 cp -v /usr/lib64/libxcb-*.so.[0-9] persalys.AppDir/usr/lib && rm persalys.AppDir/usr/lib/libxcb-dri3.so.0
 cp -v /usr/lib64/libfreebl3.so persalys.AppDir/usr/lib
+cp -v /lib64/libpcre2-16.so.0 persalys.AppDir/usr/lib
 
 # python
 sudo ln -sf /usr/local/bin/python3 /usr/local/bin/python
@@ -89,22 +91,22 @@ for libname in otmorris nlopt ceres cminpack bonmin ipopt coinmumps CoinUtils Cb
 do
   cp -v /usr/local/lib/lib${libname}.so.[0-9] persalys.AppDir/usr/lib
 done
-cp -v /usr/local/lib64/libpagmo.so.8 persalys.AppDir/usr/lib
-cp -v /usr/local/lib64/libtbb.so.12 persalys.AppDir/usr/lib
-cp -v /usr/local/lib64/libdlib*.0 persalys.AppDir/usr/lib
+cp -v /usr/local/lib64/libpagmo.so.* persalys.AppDir/usr/lib
+cp -v /usr/local/lib64/libtbb.so.* persalys.AppDir/usr/lib
+cp -v /usr/local/lib64/libdlib* persalys.AppDir/usr/lib
 cp -v /usr/local/lib64/libglog.so.1 persalys.AppDir/usr/lib
-cp -v /usr/local/lib64/libprimesieve.so.10 persalys.AppDir/usr/lib
+cp -v /usr/local/lib64/libprimesieve.so.* persalys.AppDir/usr/lib
 cp -v /usr/local/lib/libboost* persalys.AppDir/usr/lib
+cp -v /usr/local/lib/libmetis* persalys.AppDir/usr/lib
+cp -v /usr/local/lib/libGKlib* persalys.AppDir/usr/lib
+cp -r /usr/local/lib/libhdf5* persalys.AppDir/usr/lib
 cp -v /usr/local/lib/libOT.so.0.* persalys.AppDir/usr/lib
 cp -rv /usr/local/etc/ persalys.AppDir/etc
 
-#hdf5
-cp -r /usr/local/lib/libhdf5* persalys.AppDir/usr/lib
-
 # qt libs
-for libname in Qt5XcbQpa Qt5DBus Qt5Widgets Qt5Gui Qt5Test Qt5Core Qt5PrintSupport Qt5OpenGL Qt5Svg Qt5Concurrent Qt5Help Qt5Network Qt5X11Extras Qt5Sql Qt5WaylandClient
+for libname in XcbQpa DBus Widgets Gui Test Core PrintSupport OpenGL Svg Concurrent Help Network X11Extras Sql WaylandClient
 do
-  cp -v /usr/local/lib/lib${libname}.so.[0-9] persalys.AppDir/usr/lib
+  cp -v /usr/local/lib/libQt5${libname}.so.[0-9] persalys.AppDir/usr/lib
 done
 cp -v /usr/local/lib/libqwt.so.6.* persalys.AppDir/usr/lib
 cp -rv /usr/local/lib/qt/plugins persalys.AppDir/usr/lib
@@ -112,19 +114,21 @@ cp -rv /usr/local/lib/qt/plugins persalys.AppDir/usr/lib
 # paraview libs
 cp -v /usr/local/lib/libvtk* persalys.AppDir/usr/lib
 cp -v /usr/local/lib/libpq* persalys.AppDir/usr/lib
-cp -v /usr/local/lib/libcatalyst.so.* persalys.AppDir/usr/lib
 mkdir -p persalys.AppDir/usr/lib/paraview/plugins
 cp -rv /usr/local/lib/paraview*/plugins/BagPlotViewsAndFilters persalys.AppDir/usr/lib/paraview/plugins
 
 # modelica
-cp -rv /usr/local/lib/x86_64-linux-gnu persalys.AppDir/usr/lib
-cp -rv /usr/local/lib/omc persalys.AppDir/usr/lib
+cp -rv /usr/local/lib64/omc persalys.AppDir/usr/lib
 cp -rv /usr/local/include/omc persalys.AppDir/usr/include
 cp -rv /usr/local/share/omc persalys.AppDir/usr/share
 cp -v /usr/lib64/liblpsolve55.so /lib64/libuuid.so.1 /lib64/libexpat.so.1 persalys.AppDir/usr/lib
 cp -v /usr/local/bin/omc persalys.AppDir/usr/bin
 cp -v /usr/local/lib/libsundials* persalys.AppDir/usr/lib
 
+# gdb
+cp -v /usr/local/bin/gdb* persalys.AppDir/usr/bin
+cp -v /usr/lib64/libtinfo.so.5 /usr/lib64/libncursesw.so.5 /usr/lib64/libpanelw.so.5 persalys.AppDir/usr/lib
+
 LD_LIBRARY_PATH=$PWD/persalys.AppDir/usr/lib ldd persalys.AppDir/usr/lib/plugins/platforms/libqxcb.so
 LD_LIBRARY_PATH=$PWD/persalys.AppDir/usr/lib ldd persalys.AppDir/usr/bin/persalys
 
