@@ -2,7 +2,7 @@
 /**
  *  @brief Parser for Ansys files
  *
- *  Copyright 2015-2023 EDF-Phimeca
+ *  Copyright 2015-2024 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -24,7 +24,7 @@
 
 #include "openturns/XMLToolbox.hxx"
 
-#include <boost/filesystem.hpp>
+#include <filesystem>
 #include <regex>
 
 using namespace OT;
@@ -299,8 +299,8 @@ std::map<String, std::pair<String, String> > AnsysParser::getSystems() const
 void AnsysParser::generateTemplate(const int indStep)
 {
   String name = "input" + std::to_string(indStep) + ".wbjn.in";
-  templateFileName_ = (boost::filesystem::path(modelFileName_).parent_path()
-                       / boost::filesystem::path(name)).string();
+  templateFileName_ = (std::filesystem::path(modelFileName_).parent_path()
+                       / std::filesystem::path(name)).string();
   outputFileName_ = "output" + std::to_string(indStep) + ".csv";
   generateTemplate(templateFileName_, outputFileName_);
 }
@@ -334,7 +334,7 @@ void AnsysParser::generateTemplate(const String & templateFileName,
   int i = 1;
   for (auto const& sys : systems_)
   {
-    templateFile << "system" << i << " = GetSystem(Name=\"" << sys.first <<"\")\n";
+    templateFile << "system" << i << " = GetSystem(Name=\"" << sys.first << "\")\n";
     templateFile << "system" << i << ".Update(AllDependencies=True)\n";
     ++i;
   }
@@ -360,7 +360,6 @@ void AnsysParser::populateCouplingStep(CouplingPhysicalModel *model,
   CouplingStep cs(csColl[indStep]);
 
   CouplingInputFileCollection inColl;
-  CouplingOutputFileCollection outColl;
 
   CouplingInputFile inFile(getTemplateFileName());
   const InputCollection inputs = getInputVariables();
@@ -370,7 +369,7 @@ void AnsysParser::populateCouplingStep(CouplingPhysicalModel *model,
   for (UnsignedInteger i = 0; i < inputs.getSize(); ++i)
   {
     inNames.add(inputs[i].getName());
-    inTokens.add("@"+inputs[i].getName()+"@");
+    inTokens.add("@" + inputs[i].getName() + "@");
     inFormats.add("{}");
     if(!model->hasInputNamed(inputs[i].getName()))
       model->PhysicalModelImplementation::addInput(inputs[i]);
@@ -388,7 +387,7 @@ void AnsysParser::populateCouplingStep(CouplingPhysicalModel *model,
   OSS cmd;
   cmd << "\"" << getExecutableFileName() << "\""
       << " -B -F \"" << modelFileName_
-      << "\" -R input" << EscapePath(std::to_string(indStep)) << ".wbjn";
+      << "\" -R input" << std::to_string(indStep) << ".wbjn";
   cs.setCommand(cmd);
   cs.setIsShell(true);
   cs.setEnvironment(Description({"PYTHONPATH", "PYTHONHOME"}), Description(2, ""));
@@ -398,7 +397,7 @@ void AnsysParser::populateCouplingStep(CouplingPhysicalModel *model,
   {
     code << "def read_output():\n";
     code << "    import os\n";
-    code << "    with open(os.path.join(workdir, '" << getOutputFileName() <<"'), 'r') as f:\n";
+    code << "    with open(os.path.join(workdir, '" << getOutputFileName() << "'), 'r') as f:\n";
     code << "        for line in f.read().splitlines():\n";
     code << "            if line.startswith('N'):# 'Name|Nom' en|fr|de, !jp\n";
     code << "                names = line.split(',')[1:]\n";
@@ -410,11 +409,11 @@ void AnsysParser::populateCouplingStep(CouplingPhysicalModel *model,
       code << "    " << getOutputVariables()[i].getName() << " = float(results['"
            << getOutputVariables()[i].getName() << "'])\n";
     code << "    return ";
-    for(UnsignedInteger i = 0; i < getOutputVariables().getSize()-1; ++i)
+    for(UnsignedInteger i = 0; i < getOutputVariables().getSize() - 1; ++i)
       code << getOutputVariables()[i].getName() << ",";
-    code << getOutputVariables()[getOutputVariables().getSize()-1].getName();
+    code << getOutputVariables()[getOutputVariables().getSize() - 1].getName();
   }
-  cs.setCode(EscapeQuotes(code));
+  cs.setCode(code);
 
   csColl[indStep] = cs;
   model->setSteps(csColl);
