@@ -2,7 +2,7 @@
 /**
  *  @brief Class for approximation reliability analysis
  *
- *  Copyright 2015-2023 EDF-Phimeca
+ *  Copyright 2015-2024 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -32,7 +32,7 @@ ApproximationAnalysis::ApproximationAnalysis()
   : optimizationAlgorithm_(AbdoRackwitz())
   , physicalStartingPoint_()
 {
-  optimizationAlgorithm_.setMaximumEvaluationNumber(1000);
+  optimizationAlgorithm_.setMaximumCallsNumber(1000);
 }
 
 
@@ -92,4 +92,4 @@ void ApproximationAnalysis::load(Advocate & adv)
   adv.loadAttribute("optimizationAlgorithm_", optimizationAlgorithm_);
   adv.loadAttribute("physicalStartingPoint_", physicalStartingPoint_);
 }
-}
\ No newline at end of file
+}
