@@ -2,7 +2,7 @@
 /**
  *  @brief Input file metadata for coupling
  *
- *  Copyright 2015-2023 EDF-Phimeca
+ *  Copyright 2015-2024 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -26,7 +26,7 @@
 #include <openturns/PersistentObjectFactory.hxx>
 #include <openturns/PythonWrappingFunctions.hxx>
 
-#include <boost/filesystem.hpp>
+#include <filesystem>
 
 using namespace OT;
 
@@ -60,7 +60,7 @@ void CouplingInputFile::setPath(const String & path)
   if (getConfiguredPath().empty())
   {
     // by default the configured path is the basename of the template path, minus the ".in" extension
-    String configuredPath(boost::filesystem::path(path).filename().string());
+    String configuredPath(std::filesystem::path(path).filename().string());
     std::size_t pos = configuredPath.find(".in");
     if (pos != std::string::npos)
       configuredPath = configuredPath.substr(0, pos);
@@ -76,7 +76,7 @@ String CouplingInputFile::getPath() const
 /* Template path accessor */
 void CouplingInputFile::setConfiguredPath(const String & configuredPath)
 {
-  if (boost::filesystem::path(configuredPath).is_absolute())
+  if (std::filesystem::path(configuredPath).is_absolute())
     throw InvalidArgumentException(HERE) << "Configured path must be relative";
   configuredPath_ = configuredPath;
 }
@@ -94,7 +94,7 @@ void CouplingInputFile::setVariables(const Description & variableNames,
   if (variableNames.getSize() != tokens.getSize())
     throw InvalidArgumentException(HERE) << "Variable names size must match tokens size";
   ValidateVariables(variableNames);
-  variableNames_= variableNames;
+  variableNames_ = variableNames;
   tokens_ = tokens;
   formats_ = formats;
 }
@@ -123,16 +123,17 @@ void CouplingInputFile::simulateInput(VariableCollection varColl) const
   code << "import os\n";
   code << "import openturns.coupling_tools as otct\n";
   code << "import persalys\n";
-  code << "input_file = persalys.CouplingInputFile('"<<EscapePath(getPath())<<"')\n";
-  code << "input_file.setConfiguredPath('" << EscapePath(getConfiguredPath())<<"')\n";
+  code << "input_file = persalys.CouplingInputFile(r'" << getPath() << "')\n";
+  code << "input_file.setConfiguredPath(r'" << getConfiguredPath() << "')\n";
   code << "input_file.setVariables("
-       << Parameters::GetOTDescriptionStr(getVariableNames())<<", "
-       << Parameters::GetOTDescriptionStr(getTokens())<<", "
-       << Parameters::GetOTDescriptionStr(getFormats())<<")\n";
+       << Parameters::GetOTDescriptionStr(getVariableNames()) << ", "
+       << Parameters::GetOTDescriptionStr(getTokens()) << ", "
+       << Parameters::GetOTDescriptionStr(getFormats()) << ")\n";
   code << "all_vars = dict(zip(" << Parameters::GetOTDescriptionStr(variableNames) << ", [";
   for (UnsignedInteger i = 0; i < varColl.getSize(); ++ i)
   {
-    if(variableNames.contains(varColl[i].getName())) {
+    if(variableNames.contains(varColl[i].getName()))
+    {
       code << varColl[i].getValue();
       if (i < varColl.getSize() - 1)
         code << ", ";
