@@ -2,7 +2,7 @@
 /**
  *  @brief Intermediate coupling step
  *
- *  Copyright 2015-2022 EDF-Phimeca
+ *  Copyright 2015-2024 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -19,7 +19,6 @@
  *
  */
 #include "persalys/CouplingPhysicalModel.hxx"
-#include "persalys/PythonScriptEvaluation.hxx"
 #include "persalys/BaseTools.hxx"
 #include "persalys/FileMemoizeFunction.hxx"
 
@@ -37,7 +36,7 @@ static Factory<PersistentCollection<CouplingStep> > Factory_PersistentCollection
 
 /* Default constructor */
 CouplingPhysicalModel::CouplingPhysicalModel(const OT::String & name,
-                                             const CouplingStepCollection & steps)
+    const CouplingStepCollection & steps)
   : PythonPhysicalModel(name)
   , cleanupWorkDirectory_(true)
 {
@@ -46,9 +45,9 @@ CouplingPhysicalModel::CouplingPhysicalModel(const OT::String & name,
 
 /* Default constructor */
 CouplingPhysicalModel::CouplingPhysicalModel(const OT::String & name,
-                                             const InputCollection & inputs,
-                                             const OutputCollection & outputs,
-                                             const CouplingStepCollection & steps)
+    const InputCollection & inputs,
+    const OutputCollection & outputs,
+    const CouplingStepCollection & steps)
   : PythonPhysicalModel(name)
   , cleanupWorkDirectory_(true)
 {
@@ -83,14 +82,16 @@ String CouplingPhysicalModel::getStepsMacro(const String & offset) const
       const CouplingInputFile inputFile(inputFiles[j]);
       if (inputFile.getPath().empty())
         continue;
-      oss << offset << "input_file" << j << " = persalys.CouplingInputFile('"<<EscapePath(inputFile.getPath())<<"')\n";
-      oss << offset << "input_file" << j <<".setConfiguredPath('" << EscapePath(inputFile.getConfiguredPath())<<"')\n";
+      oss << offset << "input_file" << j << " = persalys.CouplingInputFile(r'"
+          << inputFile.getPath() << "')\n";
+      oss << offset << "input_file" << j << ".setConfiguredPath(r'"
+          << inputFile.getConfiguredPath() << "')\n";
       if (inputFile.getVariableNames().getSize() > 0)
-        oss << offset << "input_file" << j <<".setVariables("
-            << Parameters::GetOTDescriptionStr(inputFile.getVariableNames())<<", "
-            << Parameters::GetOTDescriptionStr(inputFile.getTokens())<<", "
-            << Parameters::GetOTDescriptionStr(inputFile.getFormats())<<")\n";
-      oss << offset << "input_files.append(input_file"<<j<<")\n";
+        oss << offset << "input_file" << j << ".setVariables("
+            << Parameters::GetOTDescriptionStr(inputFile.getVariableNames()) << ", "
+            << Parameters::GetOTDescriptionStr(inputFile.getTokens()) << ", "
+            << Parameters::GetOTDescriptionStr(inputFile.getFormats()) << ")\n";
+      oss << offset << "input_files.append(input_file" << j << ")\n";
     }
     const CouplingResourceFileCollection resourceFiles(step.getResourceFiles());
     oss << offset << "resource_files = []\n";
@@ -99,8 +100,9 @@ String CouplingPhysicalModel::getStepsMacro(const String & offset) const
       const CouplingResourceFile resourceFile(resourceFiles[j]);
       if (resourceFile.getPath().empty())
         continue;
-      oss << offset << "resource_file" << j << " = persalys.CouplingResourceFile('"<<EscapePath(resourceFile.getPath())<<"')\n";
-      oss << offset << "resource_files.append(resource_file"<<j<<")\n";
+      oss << offset << "resource_file" << j << " = persalys.CouplingResourceFile(r'"
+          << resourceFile.getPath() << "')\n";
+      oss << offset << "resource_files.append(resource_file" << j << ")\n";
     }
     const CouplingOutputFileCollection outputFiles(step.getOutputFiles());
     oss << offset << "output_files = []\n";
@@ -109,23 +111,29 @@ String CouplingPhysicalModel::getStepsMacro(const String & offset) const
       const CouplingOutputFile outputFile(outputFiles[j]);
       if (outputFile.getPath().empty())
         continue;
-      oss << offset << "output_file" << j << " = persalys.CouplingOutputFile('"<<EscapePath(outputFile.getPath())<<"')\n";
+      oss << offset << "output_file" << j << " = persalys.CouplingOutputFile(r'"
+          << outputFile.getPath() << "')\n";
       if (outputFile.getVariableNames().getSize() > 0)
         oss << offset << "output_file" << j
-	    <<".setVariables("
-	    << Parameters::GetOTDescriptionStr(outputFile.getVariableNames())
-	    <<", "<<Parameters::GetOTDescriptionStr(EscapeSpecialCharacters(outputFile.getTokens()))
-	    <<", "<< Parameters::GetOTPointStr(outputFile.getSkipTokens())
-	    <<", "<< Parameters::GetOTPointStr(outputFile.getSkipLines())
-	    <<", "<< Parameters::GetOTPointStr(outputFile.getSkipColumns())<<")\n";
-      oss << offset << "output_files.append(output_file"<<j<<")\n";
+            << ".setVariables("
+            << Parameters::GetOTDescriptionStr(outputFile.getVariableNames())
+            << ", " << Parameters::GetOTDescriptionStr(EscapeSpecialCharacters(outputFile.getTokens()))
+            << ", " << Parameters::GetOTPointStr(outputFile.getSkipTokens())
+            << ", " << Parameters::GetOTPointStr(outputFile.getSkipLines())
+            << ", " << Parameters::GetOTPointStr(outputFile.getSkipColumns()) << ")\n";
+      oss << offset << "output_files.append(output_file" << j << ")\n";
     }
     // escape backslashes and single quotes
-    oss << offset << "step" << i << " = persalys.CouplingStep('"<<EscapeQuotes(EscapePath(step.getCommand()))<<"', input_files, resource_files, output_files)\n";
-    oss << offset << "step" << i << ".setIsShell(" << (step.getIsShell() ? "True": "False") << ")\n";
+    oss << offset << "step" << i << " = persalys.CouplingStep(r'"
+        << step.getCommand() << "', input_files, resource_files, output_files)\n";
+    oss << offset << "step" << i << ".setIsShell(" << (step.getIsShell() ? "True" : "False") << ")\n";
     if(!step.getCode().empty())
-      oss << offset << "step" << i << ".setCode('" << step.getEscapedCode() << "')\n";
-    oss << offset << "steps.append(step"<<i<<")\n";
+      oss << offset << "step" << i << ".setCode(\"" << step.getEscapedCode() << "\")\n";
+    oss << offset << "step" << i << ".setEnvironment("
+        << Parameters::GetOTDescriptionStr(step.getEnvironmentKeys()) << ", "
+        << Parameters::GetOTDescriptionStr(step.getEnvironmentValues()) << ")\n";
+
+    oss << offset << "steps.append(step" << i << ")\n";
   }
   return oss;
 }
@@ -159,10 +167,10 @@ void CouplingPhysicalModel::updateCode()
           outputNames.add(variableNames[k]);
       }
     }
-    if(!step.getCode().empty())
-      for(UnsignedInteger i=0; i<step.getPPOutputs().getSize(); ++i)
-        if(!outputNames.contains(step.getPPOutputs()[i]))
-          outputNames.add(step.getPPOutputs()[i]);
+    if (!step.getCode().empty())
+      for (UnsignedInteger j = 0; j < step.getPPOutputs().getSize(); ++ j)
+        if (!outputNames.contains(step.getPPOutputs()[j]))
+          outputNames.add(step.getPPOutputs()[j]);
   }
 
   // retrieve input variables
@@ -182,11 +190,11 @@ void CouplingPhysicalModel::updateCode()
           inputNames.add(variableNames[k]);
       }
     }
-    if(!step.getCode().empty())
-      for(UnsignedInteger i=0; i<step.getPPInputs().getSize(); ++i)
-        if(!inputNames.contains(step.getPPInputs()[i]) &&
-           !outputNames.contains(step.getPPInputs()[i]))
-          inputNames.add(step.getPPInputs()[i]);
+    if (!step.getCode().empty())
+      for (UnsignedInteger j = 0; j < step.getPPInputs().getSize(); ++ j)
+        if (!inputNames.contains(step.getPPInputs()[j]) &&
+            !outputNames.contains(step.getPPInputs()[j]))
+          inputNames.add(step.getPPInputs()[j]);
   }
   OSS code;
   code << "import tempfile\n";
@@ -220,7 +228,7 @@ void CouplingPhysicalModel::updateCode()
   code << "    [checksum.update(hex(struct.unpack('<Q', struct.pack('<d', x))[0]).encode()) for x in all_vars.values()]\n";
   code << "    global workdir\n";
   if(!workDir_.empty())
-    code << "    workdir = os.path.join('"+EscapeQuotes(EscapePath(workDir_))+"', 'persalys_' + checksum.hexdigest())\n";
+    code << "    workdir = os.path.join(r'" << workDir_ << "', 'persalys_' + checksum.hexdigest())\n";
   else
     code << "    workdir = os.path.join(tempfile.gettempdir(), 'persalys_' + checksum.hexdigest())\n";
   code << "    if not os.path.exists(workdir):\n";
@@ -250,7 +258,13 @@ void CouplingPhysicalModel::updateCode()
   code << "            timeout = step.getTimeOut()\n";
   code << "            if timeout <= 0:\n";
   code << "                timeout = None\n";
-  code << "            otct.execute(step.getCommand(), cwd=workdir, shell=step.getIsShell(), capture_output=True, timeout=timeout)\n";
+  code << "            if len(step.getEnvironmentKeys()) == 0:\n";
+  code << "                otct.execute(step.getCommand(), cwd=workdir, shell=step.getIsShell(), capture_output=True, timeout=timeout)\n";
+  code << "            else:\n";
+  code << "                env = os.environ.copy()\n";
+  code << "                for key, val in zip(step.getEnvironmentKeys(), step.getEnvironmentValues()):\n";
+  code << "                    env[key] = val\n";
+  code << "                otct.execute(step.getCommand(), cwd=workdir, shell=step.getIsShell(), capture_output=True, timeout=timeout, env=env)\n";
   code << "        for output_file in step.getOutputFiles():\n";
   code << "            if not output_file.getPath():\n";
   code << "                continue\n";
@@ -290,7 +304,7 @@ void CouplingPhysicalModel::updateCode()
 
   for (UnsignedInteger i = 0; i < outputNames.getSize(); ++ i)
   {
-    code << "    " << outputNames[i] <<" = all_vars['" << outputNames[i] << "']\n";
+    code << "    " << outputNames[i] << " = all_vars['" << outputNames[i] << "']\n";
   }
   code << "    return ";
   for (UnsignedInteger i = 0; i < outputNames.getSize(); ++ i)
@@ -376,8 +390,9 @@ String CouplingPhysicalModel::getPythonScript() const
 
   oss << getStepsMacro();
   oss << getName() + " = persalys." << getClassName() << "('" << getName() << "', inputs, outputs, steps)\n";
-  oss << getName() + ".setCleanupWorkDirectory(" << (getCleanupWorkDirectory() ? "True": "False") << ")\n";
-  oss << getName() + ".setCacheFiles('" << EscapePath(getCacheInputFile()) << "', '"<<EscapePath(getCacheOutputFile()) <<"')\n";
+  oss << getName() + ".setCleanupWorkDirectory(" << (getCleanupWorkDirectory() ? "True" : "False") << ")\n";
+  oss << getName() + ".setCacheFiles(r'" << getCacheInputFile()
+      << "', r'" << getCacheOutputFile() << "')\n";
   oss << PhysicalModelImplementation::getCopulaPythonScript();
 
   return oss;
