@@ -2,7 +2,7 @@
 /**
  *  @brief Evaluates the design of experiments
  *
- *  Copyright 2015-2023 EDF-Phimeca
+ *  Copyright 2015-2024 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -111,6 +111,12 @@ void DesignOfExperimentEvaluation::initialize()
 }
 
 
+bool DesignOfExperimentEvaluation::StopRequested(void* state)
+{
+  DesignOfExperimentEvaluation * p_it = reinterpret_cast<DesignOfExperimentEvaluation*>(state);
+  return p_it->stopRequested_;
+}
+
 void DesignOfExperimentEvaluation::launch()
 {
   // check
@@ -148,6 +154,9 @@ void DesignOfExperimentEvaluation::launch()
 
   Function function(getPhysicalModel().getFunction(getInterestVariables()));
 
+  // stopCallback
+  function.setStopCallback(&StopRequested, this);
+
   // iterations
   for (UnsignedInteger i = 0; i < nbIter; ++i)
   {
@@ -187,6 +196,10 @@ void DesignOfExperimentEvaluation::launch()
       blockOutputSample = blockOutputSample.getMarginal(getInterestVariables());
       blockInputSample = blockInputSample.select(ex.getSucceededIndices());
     }
+    catch (const DetachedException &)
+    {
+      throw DetachedException(HERE) << "__DETACHED_EXCEPTION__";
+    }
     catch (const std::exception& ex)
     {
       failedSample = blockInputSample;
