@@ -2,7 +2,7 @@
 /**
  *  @brief This class is a Function with history of input and output.
  *
- *  Copyright 2015-2023 EDF-Phimeca
+ *  Copyright 2015-2024 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -27,7 +27,8 @@
 
 using namespace OT;
 
-namespace PERSALYS {
+namespace PERSALYS
+{
 
 CLASSNAMEINIT(FileMemoizeFunction)
 
@@ -65,18 +66,6 @@ String FileMemoizeFunction::__repr__() const
   return FunctionImplementation::__repr__();
 }
 
-/** Operator () */
-Point FileMemoizeFunction::operator() (const Point & inPoint) const
-{
-  return getEvaluation().operator()(inPoint);
-}
-
-/** Operator () */
-Sample FileMemoizeFunction::operator() (const Sample & inSample) const
-{
-  return getEvaluation().operator()(inSample);
-}
-
 /* Function implementation accessors */
 void FileMemoizeFunction::setEvaluation(const Evaluation & evaluation)
 {
