@@ -2,7 +2,7 @@
 /**
  *  @brief Class to define kriging
  *
- *  Copyright 2015-2023 EDF-Phimeca
+ *  Copyright 2015-2024 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -163,7 +163,7 @@ void KrigingAnalysis::launch()
   const Point stddev(effectiveOutputSample.computeStandardDeviation());
   for (UnsignedInteger i = 0; i < outputDimension; ++ i)
     if (!(stddev[i] > 0.0))
-      throw InvalidArgumentException(HERE) << "No variance for output variable "<< outputVariables[i];
+      throw InvalidArgumentException(HERE) << "No variance for output variable " << outputVariables[i];
 
   // Kriging
 
@@ -185,9 +185,10 @@ void KrigingAnalysis::launch()
     const Point stddevInput(effectiveInputSample.computeStandardDeviation());
     SquareMatrix linear(inputDimension);
     for (UnsignedInteger j = 0; j < inputDimension; ++ j)
-        linear(j, j) = (std::abs(stddevInput[j]) > 1e-12) ? 1.0 / stddevInput[j] : 1.0;
+      linear(j, j) = (std::abs(stddevInput[j]) > 1e-12) ? 1.0 / stddevInput[j] : 1.0;
     const Point zero(inputDimension, 0.0);
     normalization_ = LinearFunction(mean, zero, linear);
+    normalization_.setInputDescription(effectiveInputSample.getDescription());
 
     // build algo
     KrigingAlgorithm kriging(buildKrigingAlgorithm(effectiveInputSample, effectiveOutputSample.getMarginal(i)));
@@ -230,6 +231,7 @@ void KrigingAnalysis::launch()
 
   buildMetaModel(result_, metamodelFunction);
   result_.metaModelOutputSample_ = metamodelFunction(effectiveInputSample);
+  notify("metamodelAvailable");
 
   // validations
   validateMetaModelResult(allResults, effectiveInputSample);
@@ -356,10 +358,8 @@ void KrigingAnalysis::validateMetaModelResult(Collection<KrigingAnalysisResult>
 void KrigingAnalysis::computeAnalyticalValidation(MetaModelAnalysisResult& result, const Sample& inputSample)
 {
   if (stopRequested_)
-  {
-    analyticalValidation_ = false;
     return;
-  }
+
   informationMessage_ = "The analytical validation is running.";
   notify("informationMessageUpdated");
 
