@@ -2,7 +2,7 @@
 /**
  *  @brief MetaModel implements models created by MetaModelAnalysis
  *
- *  Copyright 2015-2023 EDF-Phimeca
+ *  Copyright 2015-2024 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -42,8 +42,8 @@ MetaModel::MetaModel(const String& name)
 /* Constructor with parameters */
 MetaModel::MetaModel(const OT::String& name, const OT::Function& function)
   : PhysicalModelImplementation(name)
-  , function_(function)
 {
+  setFunction(function);
 }
 
 
