@@ -2,7 +2,7 @@
 /**
  *  @brief Class to define outputs of the physical models
  *
- *  Copyright 2015-2023 EDF-Phimeca
+ *  Copyright 2015-2024 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -36,8 +36,6 @@ static Factory<Output> Factory_Output;
 /* Default constructor */
 Output::Output()
   : Variable()
-  , isSelected_(true)
-  , hasBeenComputed_(false)
 {
 }
 
@@ -45,8 +43,6 @@ Output::Output()
 /* Constructor with parameters */
 Output::Output(const String& name, const String& description, const String& unit)
   : Variable(name, 0., description, unit)
-  , isSelected_(true)
-  , hasBeenComputed_(false)
 {
 }
 
@@ -54,8 +50,6 @@ Output::Output(const String& name, const String& description, const String& unit
 Output::Output(const String& name, const double& value,
                const String& description, const String& unit)
   : Variable(name, value, description, unit)
-  , isSelected_(true)
-  , hasBeenComputed_(false)
 {
 }
 
@@ -66,6 +60,13 @@ Output* Output::clone() const
 }
 
 
+/* Comparison operator */
+Bool Output::operator ==(const Output & other) const
+{
+  if (this == &other) return true;
+  return Variable::operator==(other) && (isSelected_ == other.isSelected_) && (hasBeenComputed_ == other.hasBeenComputed_);
+}
+
 bool Output::isSelected() const
 {
   return isSelected_;
