@@ -2,7 +2,7 @@
 /**
  *  @brief Abstract top-level class for all physical models
  *
- *  Copyright 2015-2023 EDF-Phimeca
+ *  Copyright 2015-2024 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -436,6 +436,11 @@ String PhysicalModel::getPythonScript() const
   return getImplementation()->getPythonScript();
 }
 
+void PhysicalModel::exportStandalonePythonScript(const String & fileName) const
+{
+  getImplementation()->exportStandalonePythonScript(fileName);
+}
+
 
 /* Method save() stores the object through the StorageManager */
 void PhysicalModel::save(Advocate& adv) const
