@@ -2,7 +2,7 @@
 /**
  *  @brief Linear metamodel
  *
- *  Copyright 2015-2023 EDF-Phimeca
+ *  Copyright 2015-2024 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -188,6 +188,7 @@ void PolynomialRegressionAnalysis::launch()
   buildMetaModel(result_, metamodelFunction);
   result_.metaModelOutputSample_ = metamodelFunction(effectiveInputSample);
   result_.formulas_ = formulas;
+  notify("metamodelAvailable");
 
   // validations
   validateMetaModelResult(result_, effectiveInputSample);
@@ -240,10 +241,8 @@ LinearModelStepwiseAlgorithm PolynomialRegressionAnalysis::buildAlgo(const OT::S
 void PolynomialRegressionAnalysis::computeAnalyticalValidation(MetaModelAnalysisResult& result, const Sample& inputSample)
 {
   if (stopRequested_)
-  {
-    analyticalValidation_ = false;
     return;
-  }
+
   informationMessage_ = "The analytical validation is running.";
   notify("informationMessageUpdated");
 
