@@ -2,7 +2,7 @@
 /**
  *  @brief PythonPhysicalModel implements models defined by a Python script
  *
- *  Copyright 2015-2023 EDF-Phimeca
+ *  Copyright 2015-2024 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -234,11 +234,7 @@ String PythonPhysicalModel::getPythonScript() const
   oss << "inputs = " << Parameters::GetOTDescriptionStr(getInputNames(), false) << "\n";
   oss << "outputs = " << Parameters::GetOTDescriptionStr(getOutputNames(), false) << "\n";
 
-  // escape triple quotes, backslashes
-  String escaped_code = std::regex_replace(getCode(), std::regex("\\\\"), "\\\\\\\\");
-  escaped_code = std::regex_replace(escaped_code, std::regex("\"\"\""), "\\\\\"\\\\\"\\\\\"");
-
-  oss << "code = \"\"\"\n" + escaped_code + "\"\"\"\n";
+  oss << "code = r'''\n" + getCode() + "'''\n";
 
   oss << getName() + " = persalys.PythonPhysicalModel('" + getName() + "', inputs, outputs, code)\n";
   if (isParallel())
