@@ -2,7 +2,7 @@
 /**
  *  @brief Analysis SORM
  *
- *  Copyright 2015-2023 EDF-Phimeca
+ *  Copyright 2015-2024 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -112,7 +112,7 @@ Parameters SORMAnalysis::getParameters() const
   param.add("Output of interest", getLimitState().getOutputName());
   param.add("Optimization algorithm", getOptimizationAlgorithm().getImplementation()->getClassName());
   param.add("Physical starting point", getPhysicalStartingPoint());
-  param.add("Maximum evaluation number", getOptimizationAlgorithm().getMaximumEvaluationNumber());
+  param.add("Maximum number of calls", getOptimizationAlgorithm().getMaximumCallsNumber());
   param.add("Maximum absolute error", getOptimizationAlgorithm().getMaximumAbsoluteError());
   param.add("Maximum relative error", getOptimizationAlgorithm().getMaximumRelativeError());
   param.add("Maximum residual error", getOptimizationAlgorithm().getMaximumResidualError());
@@ -130,7 +130,7 @@ String SORMAnalysis::getPythonScript() const
   oss << getName() << ".setPhysicalStartingPoint(" << Parameters::GetOTPointStr(getPhysicalStartingPoint()) << ")\n";
   // optimization algo
   oss << "optimizationAlgo = ot." << getOptimizationAlgorithm().getImplementation()->getClassName() << "()\n";
-  oss << "optimizationAlgo.setMaximumEvaluationNumber(" << getOptimizationAlgorithm().getMaximumEvaluationNumber() << ")\n";
+  oss << "optimizationAlgo.setMaximumCallsNumber(" << getOptimizationAlgorithm().getMaximumCallsNumber() << ")\n";
   oss << "optimizationAlgo.setMaximumAbsoluteError(" << getOptimizationAlgorithm().getMaximumAbsoluteError() << ")\n";
   oss << "optimizationAlgo.setMaximumRelativeError(" << getOptimizationAlgorithm().getMaximumRelativeError() << ")\n";
   oss << "optimizationAlgo.setMaximumResidualError(" << getOptimizationAlgorithm().getMaximumResidualError() << ")\n";
