@@ -2,7 +2,7 @@
 /**
  *  @brief Class for Reliability Analysis using simulation methods
  *
- *  Copyright 2015-2023 EDF-Phimeca
+ *  Copyright 2015-2024 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -184,9 +184,11 @@ void SimulationReliabilityAnalysis::launch()
   // set results
   // get convergence graph at level 0.95
   const Graph graph = algo.drawProbabilityConvergence();
-  for(UnsignedInteger i=0; i<graph.getDrawables().getSize(); ++i) {
-    for(UnsignedInteger j=0; j<graph.getDrawables()[i].getData().getSize(); ++j) {
-      graph.getDrawables()[i].getData().getImplementation()->operator()(j,0) *= getBlockSize();
+  for(UnsignedInteger i = 0; i < graph.getDrawables().getSize(); ++i)
+  {
+    for(UnsignedInteger j = 0; j < graph.getDrawables()[i].getData().getSize(); ++j)
+    {
+      graph.getDrawables()[i].getData().getImplementation()->operator()(j, 0) *= getBlockSize();
     }
   }
 
