@@ -2,7 +2,7 @@
 /**
  *  @brief SobolAnalysis computes the Sobol indices
  *
- *  Copyright 2015-2023 EDF-Phimeca
+ *  Copyright 2015-2024 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -109,7 +109,7 @@ void SobolAnalysis::setConfidenceLevel(const Scalar level)
   if (!(level >= 0.0) || !(level < 1.0))
     throw InvalidArgumentException(HERE) << "Confidence level value should be in ]0,1[. Here, confidence level=" << level;
   confidenceLevel_ = level;
- }
+}
 
 
 void SobolAnalysis::initialize()
@@ -273,7 +273,6 @@ void SobolAnalysis::launch()
       // initialization
       RandomGenerator::SetSeed(getSeed());
 
-      const Description outputName(1, getInterestVariables()[i]);
       MartinezSensitivityAlgorithm estimator_i;
       estimator_i.setUseAsymptoticDistribution(true);
       SobolSimulationAlgorithm algo_i(getPhysicalModel().getDistribution(),
