@@ -2,7 +2,7 @@
 /**
  *  @brief Class defining the persalys studies
  *
- *  Copyright 2015-2023 EDF-Phimeca
+ *  Copyright 2015-2024 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -28,7 +28,6 @@
 #include <openturns/WeibullMin.hxx>
 #include <openturns/ThresholdEventImplementation.hxx>
 
-#include <boost/filesystem.hpp>
 #include <locale>
 #include <codecvt>
 
@@ -155,19 +154,22 @@ Study Study::Open(const String & xmlFileName)
 {
   OT::Study study;
   Study openedStudy;
-  try {
+  try
+  {
     study.setStorageManager(XMLH5StorageManager(xmlFileName));
     study.load();
     study.fillObject("aStudy", openedStudy);
   }
-  catch (Exception &) {
+  catch (Exception &)
+  {
     // if setting XMLH5SM fails, it may be due to missing H5 file or pure XML study
     // therefore, XML file is scrutinised to find any H5 dataset
     Pointer<XMLDoc> doc = new XMLDoc(xmlFileName);
     XML::Node root = XML::GetRootNode(*doc);
     XML::Node node = XML::GetFirstChild(root);
     // loop over all xml nodes
-    while( node ) {
+    while( node )
+    {
       std::regex h5dataset(".+\\.h5\\:\\/[0-9]+");
       OT::String nodeVal = XML::GetNodeValue(XML::FindElementByName(node, XML_STMGR::string_tag::Get() ));
       // if H5 DS is found, throw exception
