@@ -2,7 +2,7 @@
 /**
  *  @brief Coupling model through YACS
  *
- *  Copyright 2015-2023 EDF-Phimeca
+ *  Copyright 2015-2024 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -24,7 +24,7 @@
 #include "persalys/FileMemoizeFunction.hxx"
 
 #include <openturns/PersistentObjectFactory.hxx>
-#include <boost/filesystem.hpp>
+#include <filesystem>
 
 using namespace OT;
 
@@ -37,7 +37,7 @@ static Factory<YACSCouplingPhysicalModel> Factory_YACSCouplingPhysicalModel;
 
 /* Default constructor */
 YACSCouplingPhysicalModel::YACSCouplingPhysicalModel(const String & name,
-                                                     const CouplingStepCollection & steps)
+    const CouplingStepCollection & steps)
   : CouplingPhysicalModel(name, steps)
   , evaluation_()
 {
@@ -46,9 +46,9 @@ YACSCouplingPhysicalModel::YACSCouplingPhysicalModel(const String & name,
 
 /* Default constructor */
 YACSCouplingPhysicalModel::YACSCouplingPhysicalModel(const String & name,
-                                                     const InputCollection & inputs,
-                                                     const OutputCollection & outputs,
-                                                     const CouplingStepCollection & steps)
+    const InputCollection & inputs,
+    const OutputCollection & outputs,
+    const CouplingStepCollection & steps)
   : CouplingPhysicalModel(name, inputs, outputs, steps)
   , evaluation_()
 {
@@ -96,14 +96,14 @@ void YACSCouplingPhysicalModel::setCode(const String & script)
     {
       const CouplingInputFile inputFile(inputFiles[j]);
       // yacs wants absolute paths
-      inFiles.push_back(boost::filesystem::absolute(inputFile.getPath()).string());
+      inFiles.push_back(std::filesystem::absolute(inputFile.getPath()).string());
     }
     const CouplingResourceFileCollection resourceFiles(step.getResourceFiles());
     for (UnsignedInteger j = 0; j < resourceFiles.getSize(); ++ j)
     {
       const CouplingResourceFile resourceFile(resourceFiles[j]);
       // yacs wants absolute paths
-      inFiles.push_back(boost::filesystem::absolute(resourceFile.getPath()).string());
+      inFiles.push_back(std::filesystem::absolute(resourceFile.getPath()).string());
     }
   }
   jobParameters().in_files(inFiles);
