@@ -2,7 +2,7 @@
 /**
  *  @brief YACSEvaluation implements the evaluation of the models defined by an xml file
  *
- *  Copyright 2015-2022 EDF-Phimeca
+ *  Copyright 2015-2024 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -21,7 +21,11 @@
 #include "persalys/YACSEvaluation.hxx"
 
 #include <openturns/PersistentObjectFactory.hxx>
+#include <openturns/BatchFailedException.hxx>
 #include "persalys/InterpreterUnlocker.hxx"
+#include "persalys/BaseTools.hxx"
+#include "persalys/AppliException.hxx"
+#include <thread> //std::this_thread
 #include <memory> //std::unique_ptr
 #include <cmath> //std::nan
 
@@ -37,11 +41,6 @@ static Factory<YACSEvaluation> Factory_YACSEvaluation;
 /* Default constructor */
 YACSEvaluation::YACSEvaluation(const String & script)
   : EvaluationImplementation()
-  , inputValues_()
-  , inDescription_()
-  , outDescription_()
-  , jobParams_()
-  , studyFunction_()
 {
   if (!script.empty())
     setContent(script);
@@ -98,7 +97,7 @@ Sample YACSEvaluation::operator() (const Sample & inS) const
   if(!studyFunction_.isValid())
   {
     Log::Error(OSS() << "Invalid study function: " << studyFunction_.errors()
-                     << "\n");
+               << "\n");
     throw InvalidArgumentException(HERE) << "The study function is incorrect: "
                                          << studyFunction_.errors() ;
   }
@@ -108,9 +107,9 @@ Sample YACSEvaluation::operator() (const Sample & inS) const
   if (inputNames.size() != inS.getDimension())
   {
     Log::Error(OSS() <<
-    "In YACSEvaluation::operator(): inputNames.size() != inS.getDimension()\n");
+               "In YACSEvaluation::operator(): inputNames.size() != inS.getDimension()\n");
     throw InvalidArgumentException(HERE) << "The dimension of the input sample "
-                                       << inS.getDimension() << " is not valid";
+                                         << inS.getDimension() << " is not valid";
   }
   ydefx::Sample<double> jobSample;
   // set default value for not computed and failed points
@@ -131,7 +130,6 @@ Sample YACSEvaluation::operator() (const Sample & inS) const
 
   Sample result(inS.getSize(), getOutputDimension());
   result.setDescription(getOutputVariablesNames());
-
   py2cpp::PyPtr modelToUse;
   if(nullptr == jobModel_.get() )
   {
@@ -145,48 +143,77 @@ Sample YACSEvaluation::operator() (const Sample & inS) const
   }
   ydefx::Launcher l;
   std::unique_ptr<ydefx::Job> myJob;
-  try
+  if (!isRunning_)
   {
     myJob.reset(l.submitPyStudyJob(modelToUse, studyFunction_, jobSample, jobParams_));
-    if(myJob)
+    setIsRunning(true);
+  }
+  else
+  {
+    myJob.reset(l.connectJob(dump_, jobSample));
+  }
+  if(myJob)
+  {
+    double progress = myJob->progress();
+    while(progress < 1.0)
     {
-      myJob->wait();
-      if(!myJob->fetch())
-        throw NotDefinedException(HERE) << myJob->lastError();
+      if (stopCallback_.first)
+      {
+        const Bool stop = stopCallback_.first(stopCallback_.second);
+        if (stop)
+        {
+          setDump(myJob->dump());
+          throw DetachedException(HERE) << "Job has been detached";
+        }
+      }
+      std::this_thread::sleep_for(std::chrono::seconds(1));
+      progress = myJob->progress();
+    }
+    if (progress >= 1.0)
+      setIsRunning(false);
 
-      // get results
-      UnsignedInteger sampleSize = jobSample.maxSize();
+    if(!myJob->fetch())
+    {
+      setIsRunning(false);
+      throw NotDefinedException(HERE) << myJob->lastError();
+    }
+
+    // get results
+    UnsignedInteger sampleSize = jobSample.maxSize();
+    Indices nokIdx;
+    Description errorDesc;
+    for(UnsignedInteger j = 0; j < sampleSize; ++j)
+    {
       for (UnsignedInteger i = 0; i < getOutputDimension(); ++i)
       {
         std::string name = getOutputVariablesNames()[i];
-        for(UnsignedInteger j = 0; j < sampleSize; ++j)
-          if (checkOutput_)
-          {
-            if(ydefx::ExecutionState::DONE == jobSample.pointState(j))
-              result(j, i) = jobSample.outputs<double>().get(name, j);
-            else// the point could not have been evaluated
-              throw InternalException(HERE)
-                << "\nThe evaluation of the point number " << j
-                << " is in error:" << jobSample.getError(j)
-                << "\nFor further details, see "
-                << jobParams_.work_directory() << "/logs directory on "
-                << jobParams_.resource_name() << ".";
-          }
-	  else
-            result(j, i) = jobSample.outputs<double>().get(name, j);
+        if(ydefx::ExecutionState::DONE == jobSample.pointState(j))
+        {
+          result(j, i) = jobSample.outputs<double>().get(name, j);
+        }
+        else// the point could not have been evaluated
+        {
+          nokIdx.add(j);
+          const String message = OSS()
+                                 << "\nThe evaluation of the point number " << j
+                                 << " is in error:" << jobSample.getError(j)
+                                 << "\nFor further details, see "
+                                 << jobParams_.work_directory() << "/logs directory on "
+                                 << jobParams_.resource_name() << ".";
+          errorDesc.add(message);
+          break;
+        }
       }
     }
-    else
-      throw NotDefinedException(HERE) << l.lastError();
-  }
-  catch (InternalException& e)
-  {
-    throw;
-  }
-  catch (std::exception& e)
-  {
-    throw NotDefinedException(HERE) << e.what();
+    if (nokIdx.getSize())
+    {
+      throw BatchFailedException(HERE, nokIdx, errorDesc,
+                                 nokIdx.complement(sampleSize),
+                                 result.select(nokIdx.complement(sampleSize)));
+    }
   }
+  else
+    throw NotDefinedException(HERE) << l.lastError();
   return result;
 }
 
@@ -255,6 +282,10 @@ void YACSEvaluation::setJobModel(const py2cpp::PyPtr& model)
   jobModel_ = model;
 }
 
+void YACSEvaluation::setStopCallback(StopCallback callBack, void * state)
+{
+  stopCallback_ = std::pair<StopCallback, void *>(callBack, state);
+}
 
 /* Method save() stores the object through the StorageManager */
 void YACSEvaluation::save(Advocate & adv) const
@@ -266,6 +297,8 @@ void YACSEvaluation::save(Advocate & adv) const
   for(const std::string& f : inFiles)
     listInputFiles.add(f);
   adv.saveAttribute("inputFiles_", listInputFiles);
+  adv.saveAttribute("dump_", dump_);
+  adv.saveAttribute("isRunning__", isRunning_);
 }
 
 
@@ -282,6 +315,10 @@ void YACSEvaluation::load(Advocate & adv)
   for(const std::string& f : listInputFiles)
     inFiles.push_back(f);
   jobParams_.in_files(inFiles);
+  if (adv.hasAttribute("dump_"))
+    adv.loadAttribute("dump_", dump_);
+  if (adv.hasAttribute("isRunning_"))
+    adv.loadAttribute("isRunning__", isRunning_);
 }
 
 
