@@ -2,7 +2,7 @@
 /**
  *  @brief YACSPhysicalModel implements models defined by an xml file
  *
- *  Copyright 2015-2023 EDF-Phimeca
+ *  Copyright 2015-2024 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -160,28 +160,32 @@ void YACSPhysicalModel::updateData()
     else
       newOutputs[i] = Output(outputName);
   }
+  functionCache_ = Function();
   PhysicalModelImplementation::setOutputs(newOutputs);
 }
 
 
 Function YACSPhysicalModel::generateFunction(const Description & outputNames) const
 {
-  YACSEvaluation anEvaluation(evaluation_);
-  anEvaluation.setOutputVariablesNames(outputNames);
-
-  return MemoizeFunction(Function(anEvaluation));
+  if (!functionCache_.getEvaluation().getImplementation()->isActualImplementation())
+  {
+    YACSEvaluation anEvaluation(evaluation_);
+    anEvaluation.setOutputVariablesNames(outputNames);
+    functionCache_ = MemoizeFunction(anEvaluation);
+  }
+  return functionCache_;
 }
 
 
 void YACSPhysicalModel::ReplaceInString(String& workString,
-                            const String& strToReplace,
-                            const String& newValue)
+                                        const String& strToReplace,
+                                        const String& newValue)
 {
   std::size_t pos = workString.find(strToReplace);
   while( pos != std::string::npos)
   {
     workString.replace(pos, strToReplace.size(), newValue);
-    pos = workString.find(strToReplace, pos+newValue.size());
+    pos = workString.find(strToReplace, pos + newValue.size());
   }
 }
 
