@@ -2,7 +2,7 @@
 /**
  *  @brief QAbstractTableModel to define correlations
  *
- *  Copyright 2015-2023 EDF-Phimeca
+ *  Copyright 2015-2024 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -78,14 +78,14 @@ QVariant CorrelationTableModel::data(const QModelIndex & index, int role) const
   if (role == Qt::DisplayRole || role == Qt::EditRole)
     switch(type_)
     {
-    case CorrelationTableModel::Spearman:
-      return QString::number(copula_.getSpearmanCorrelation()(index.row(), index.column()), 'g', StudyTreeViewModel::DefaultSignificantDigits);
-    case CorrelationTableModel::Correlation:
-      return QString::number(copula_.getShapeMatrix()(index.row(), index.column()), 'g', StudyTreeViewModel::DefaultSignificantDigits);
-    case CorrelationTableModel::Kendall:
-      return QString::number(copula_.getKendallTau()(index.row(), index.column()), 'g', StudyTreeViewModel::DefaultSignificantDigits);
-    default:
-       throw InvalidArgumentException(HERE) << "Unknow correlation type";
+      case CorrelationTableModel::Spearman:
+        return QString::number(copula_.getSpearmanCorrelation()(index.row(), index.column()), 'g', StudyTreeViewModel::DefaultSignificantDigits);
+      case CorrelationTableModel::Correlation:
+        return QString::number(copula_.getShapeMatrix()(index.row(), index.column()), 'g', StudyTreeViewModel::DefaultSignificantDigits);
+      case CorrelationTableModel::Kendall:
+        return QString::number(copula_.getKendallTau()(index.row(), index.column()), 'g', StudyTreeViewModel::DefaultSignificantDigits);
+      default:
+        throw InvalidArgumentException(HERE) << "Unknown correlation type";
     }
   else if (role == Qt::BackgroundRole && index.row() >= index.column())
     return QBrush(Qt::lightGray);
@@ -109,31 +109,37 @@ bool CorrelationTableModel::setData(const QModelIndex & index, const QVariant &
     emit errorMessageChanged("");
     try
     {
-      physicalModel_.blockNotification("ProbabilisticModelItem");
+      // physicalModel_ has no item if coming from CalibrationWizard
+      if (physicalModel_.getImplementation()->getObserver("ProbabilisticModelItem"))
+        physicalModel_.blockNotification("ProbabilisticModelItem");
       const Description oldDescription = copula_.getDescription();
       CorrelationMatrix correlation;
       switch(type_)
       {
-      case CorrelationTableModel::Spearman:
-        correlation = copula_.getSpearmanCorrelation();
-        correlation(index.row(), index.column()) = value.toDouble();
-        copula_ = NormalCopula(NormalCopula::GetCorrelationFromSpearmanCorrelation(correlation));
-        break;
-      case CorrelationTableModel::Correlation:
-        correlation = copula_.getShapeMatrix();
-        correlation(index.row(), index.column()) = value.toDouble();
-        copula_ = NormalCopula(correlation);
-        break;
-      case CorrelationTableModel::Kendall:
-        correlation = copula_.getKendallTau();
-        correlation(index.row(), index.column()) = value.toDouble();
-        copula_ = NormalCopula(NormalCopula::GetCorrelationFromKendallCorrelation(correlation));
-        break;
-      default:
-        throw InvalidArgumentException(HERE) << "Unknow correlation type";
+        case CorrelationTableModel::Spearman:
+          correlation = copula_.getSpearmanCorrelation();
+          if (value.toDouble() == correlation(index.row(), index.column()))
+            return true;
+          correlation(index.row(), index.column()) = value.toDouble();
+          copula_ = NormalCopula(NormalCopula::GetCorrelationFromSpearmanCorrelation(correlation));
+          break;
+        case CorrelationTableModel::Correlation:
+          correlation = copula_.getShapeMatrix();
+          if (value.toDouble() == correlation(index.row(), index.column()))
+            return true;
+          correlation(index.row(), index.column()) = value.toDouble();
+          copula_ = NormalCopula(correlation);
+          break;
+        case CorrelationTableModel::Kendall:
+          correlation = copula_.getKendallTau();
+          if (value.toDouble() == correlation(index.row(), index.column()))
+            return true;
+          correlation(index.row(), index.column()) = value.toDouble();
+          copula_ = NormalCopula(NormalCopula::GetCorrelationFromKendallCorrelation(correlation));
+          break;
+        default:
+          throw InvalidArgumentException(HERE) << "Unknown correlation type";
       }
-      if (value.toDouble() == correlation(index.row(), index.column()))
-        return true;
       copula_.setDescription(oldDescription);
       physicalModel_.setCopula(oldDescription, copula_);
       emit dataChanged(index, index);
