@@ -30,6 +30,7 @@
 #include "persalys/ObservationsItem.hxx"
 #include "persalys/FunctionalChaosAnalysis.hxx"
 #include "persalys/KrigingAnalysis.hxx"
+#include "persalys/PythonPhysicalModel.hxx"
 
 #include <openturns/PlatformInfo.hxx>
 
@@ -104,6 +105,16 @@ void PhysicalModelDiagramItem::buildActions()
   appendAction(duplicateAction_);
   appendSeparator();
   appendAction(removeAction_);
+
+  // Physical model properties action (Python PM only)
+  PythonPhysicalModel * model = dynamic_cast<PythonPhysicalModel*>(getPhysicalModel().getImplementation().get());
+  if (model)
+  {
+    propertiesAction_ = new QAction(QIcon(":/images/documentinfo.png"), tr("Properties"), this);
+    propertiesAction_->setStatusTip(tr("Physical model properties"));
+    connect(propertiesAction_, SIGNAL(triggered()), this, SLOT(requestOpenProperties()));
+    appendAction(propertiesAction_);
+  }
 }
 
 
@@ -253,6 +264,16 @@ void PhysicalModelDiagramItem::requestMetaModelExport()
   }
 }
 
+void PhysicalModelDiagramItem::requestOpenProperties()
+{
+  // Only if it is a PythonPhysicalModel
+  PythonPhysicalModel * model = dynamic_cast<PythonPhysicalModel*>(physicalModel_.getImplementation().get());
+  if (model)
+  {
+    emit openPropertiesRequested();
+  }
+}
+
 void PhysicalModelDiagramItem::requestReliabilityCreation()
 {
   for (UnsignedInteger i = 0; i < getParentStudyItem()->getStudy().getLimitStates().getSize(); ++i)
@@ -424,7 +445,7 @@ void PhysicalModelDiagramItem::appendItem(const Analysis& analysis)
   {
     AnalysisItem * newItem = dynamic_cast<AnalysisItem*>(analysis.getImplementation().get()->getObserver("AnalysisItem"));
     // connections
-    connect(newItem, SIGNAL(numberMetamodelChanged(bool)), this, SLOT(updateMetamodelCounter(bool)));
+    connect(newItem, SIGNAL(numberMetamodelChanged(int)), this, SLOT(updateMetamodelCounter(int)));
 
     if(newItem->getAnalysis().hasValidResult())
       ++metamodelCounter_;
@@ -507,12 +528,11 @@ void PhysicalModelDiagramItem::updateDesignEvaluationCounter(bool increment)
   emit doeEvaluationNumberValidityChanged(physicalModel_.isValid() && doeCounter_[1] > 0);
 }
 
-void PhysicalModelDiagramItem::updateMetamodelCounter(bool increment)
+void PhysicalModelDiagramItem::updateMetamodelCounter(int increment)
 {
-  if (increment)
-    ++metamodelCounter_;
-  else
-    --metamodelCounter_;
+  metamodelCounter_ += increment;
+  if (metamodelCounter_ < 0)
+    metamodelCounter_ = 0;
   emit metamodelNumberValidityChanged(physicalModel_.isValid() && metamodelCounter_ > 0);
 }
 
