@@ -2,7 +2,7 @@
 /**
  *  @brief QWizard to define a metamodel analysis
  *
- *  Copyright 2015-2022 EDF-Phimeca
+ *  Copyright 2015-2024 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -68,16 +68,9 @@ void FunctionalChaosPage::buildInterface()
 
   pageLayout->addWidget(parametersBox);
 
-  // functional chaos advanced parameters
-  CollapsibleGroupBox * advancedParamGroupBox = new CollapsibleGroupBox;
-  advancedParamGroupBox->setTitle(tr("Advanced parameters"));
-  QGridLayout * advancedParamGroupBoxLayout = new QGridLayout(advancedParamGroupBox);
 
   sparseCheckBox_ = new QCheckBox(tr("Sparse"));
-  advancedParamGroupBoxLayout->addWidget(sparseCheckBox_, 0, 0);
-
-  advancedParamGroupBox->setExpanded(false);
-  pageLayout->addWidget(advancedParamGroupBox);
+  chaosParametersLayout->addWidget(sparseCheckBox_, 2, 0);
 
   // error message
   errorMessageLabel_ = new TemporaryLabel;
@@ -117,7 +110,7 @@ void FunctionalChaosPage::updateBasisLabel()
 
 void FunctionalChaosPage::updateBasisSizeLabel()
 {
-  const int basisSize = SpecFunc::BinomialCoefficient(inputSampleDimension_+chaosDegreeSpinbox_->value(), chaosDegreeSpinbox_->value());
+  const int basisSize = SpecFunc::BinomialCoefficient(inputSampleDimension_ + chaosDegreeSpinbox_->value(), chaosDegreeSpinbox_->value());
   basisSizeLabel_->setText(QString::number(basisSize));
 }
 Analysis FunctionalChaosPage::getAnalysis(const String& name, const DesignOfExperiment& doe) const
@@ -131,10 +124,12 @@ Analysis FunctionalChaosPage::getAnalysis(const String& name, const DesignOfExpe
 }
 
 
-void FunctionalChaosPage::updateInputSampleSize(DesignOfExperiment doe)
+void FunctionalChaosPage::updateInputSampleSizeAndDimension(DesignOfExperiment doe)
 {
   errorMessageLabel_->reset();
   inputSampleSize_ = doe.getInputSample().getSize();
+  inputSampleDimension_ = doe.getEffectiveInputIndices().getSize();
+  updateBasisSizeLabel();
 }
 
 
