@@ -2,7 +2,7 @@
 /**
  *  @brief QWizardPage to import sample to define designs of experiments
  *
- *  Copyright 2015-2023 EDF-Phimeca
+ *  Copyright 2015-2024 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -55,8 +55,8 @@ void ImportedDesignPage::buildInterface()
   connect(sampleWidget_, SIGNAL(updateTableRequested(QString)), this, SLOT(setTable(QString)));
   connect(sampleWidget_, SIGNAL(checkColumnsRequested()), this, SLOT(checkColumns()));
 
-  estimatedTimeValueLabel_->setVisible(estimatedTimeValueLabel_->text().toFloat()>1e-6);
-  estimatedTimeLabel->setVisible(estimatedTimeValueLabel_->text().toFloat()>1e-6);
+  estimatedTimeValueLabel_->setVisible(estimatedTimeValueLabel_->text().toFloat() > 1e-6);
+  estimatedTimeLabel->setVisible(estimatedTimeValueLabel_->text().toFloat() > 1e-6);
   connect(this, SIGNAL(showTime()), estimatedTimeLabel, SLOT(show()));
   checkColumns();
 }
@@ -69,7 +69,8 @@ void ImportedDesignPage::setTable(const QString& fileName)
 
   // update widgets
   estimatedTimeValueLabel_->setText(QString::number(designOfExperiment_.getSampleFromFile().getSize()*designOfExperiment_.getPhysicalModel().getEvalTime()));
-  if(estimatedTimeValueLabel_->text().toFloat()>1e-6) {
+  if(estimatedTimeValueLabel_->text().toFloat() > 1e-6)
+  {
     estimatedTimeValueLabel_->setVisible(true);
     emit showTime();
   }
