@@ -2,7 +2,7 @@
 /**
  *  @brief QWizard for inference
  *
- *  Copyright 2015-2023 EDF-Phimeca
+ *  Copyright 2015-2024 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -21,7 +21,6 @@
 #include "persalys/InferenceWizard.hxx"
 
 #include "persalys/CheckableHeaderView.hxx"
-#include "persalys/DistributionDictionary.hxx"
 #include "persalys/DistributionsForInferenceWidget.hxx"
 #include "persalys/ResizableStackedWidget.hxx"
 #include "persalys/DoubleSpinBox.hxx"
@@ -180,14 +179,14 @@ void InferenceWizard::buildInterface()
 
   switch(inference_.getTestType())
   {
-  case InferenceAnalysis::Lilliefors:
-    testTypeComboBox_->setCurrentIndex(1);
-    break;
-  case InferenceAnalysis::Kolmogorov:
-    testTypeComboBox_->setCurrentIndex(0);
-    break;
-  default:
-    throw InvalidArgumentException(HERE) << "Unknown test type.";
+    case InferenceAnalysis::Lilliefors:
+      testTypeComboBox_->setCurrentIndex(1);
+      break;
+    case InferenceAnalysis::Kolmogorov:
+      testTypeComboBox_->setCurrentIndex(0);
+      break;
+    default:
+      throw InvalidArgumentException(HERE) << "Unknown test type.";
   }
 
   QLabel * levelLabel = new QLabel(tr("Level"));
@@ -251,13 +250,16 @@ void InferenceWizard::buildInterface()
   lillieforsMaximumSamplingSizeSpinbox_->setEnabled(enableLilliefors);
   paramICLayout->addWidget(lillieforsMaximumSamplingSizeSpinbox_, row, 1);
 
-  paramICLayout->setColumnStretch(2,1);
+  paramICLayout->setColumnStretch(2, 1);
   pageLayout->addWidget(icGroupBox);
 
-  connect(paramICCheckBox_, &QCheckBox::toggled, [=](bool toggled){
-      icLevelSpinbox_->setEnabled(toggled);});
+  connect(paramICCheckBox_, &QCheckBox::toggled, [ = ](bool toggled)
+  {
+    icLevelSpinbox_->setEnabled(toggled);
+  });
 
-  connect(testTypeComboBox_, QOverload<int>::of(&QComboBox::currentIndexChanged), [=](int index) {
+  connect(testTypeComboBox_, QOverload<int>::of(&QComboBox::currentIndexChanged), [ = ](int index)
+  {
     lillieforsPrecisionSpinbox_->setEnabled(index);
     lillieforsMinimumSamplingSizeSpinbox_->setEnabled(index);
     lillieforsMaximumSamplingSizeSpinbox_->setEnabled(index);
@@ -292,7 +294,7 @@ void InferenceWizard::updateDistListForVar(QStringList dist)
   for (int i = 0; i < dist.size(); ++i)
   {
     const String distName = TranslationManager::GetDistributionName(dist[i]);
-    distCollection.add(DistributionDictionary::BuildDistributionFactory(distName));
+    distCollection.add(DistributionFactory::GetByName(distName+"Factory"));
   }
 
   distFactoriesForEachInterestVar_[currentVarName_] = distCollection;
