@@ -2,7 +2,7 @@
 /**
  *  @brief QMdiSubWindow for the results of linear regression
  *
- *  Copyright 2015-2023 EDF-Phimeca
+ *  Copyright 2015-2024 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -113,7 +113,7 @@ void PolynomialRegressionResultWindow::buildInterface()
     QStringList valuesList;
     valuesList << QString::number(analysis->getEffectiveInputSample().getDimension());
     valuesList << QString::number(analysis->getDegree());
-    valuesList << QString::fromStdString(analysis->getInteraction() ? "yes": "no");
+    valuesList << QString::fromStdString(analysis->getInteraction() ? "yes" : "no");
     valuesList << QString::fromStdString(result_.getFormulas()[i]);
     valuesList << QString::number(result_.getLinearModelResultCollection()[i].getRSquared());
     valuesList << QString::number(result_.getLinearModelResultCollection()[i].getAdjustedRSquared());
@@ -318,7 +318,8 @@ void PolynomialRegressionResultWindow::buildInterface()
     residualTabWidget->addTab(residualTableScrollArea, tr("Table"));
 
     // residual distribution
-    try {
+    try
+    {
       QGridLayout * resDistLayout = new QGridLayout;
       const Normal noiseDistribution(result_.getLinearModelResultCollection()[i].getNoiseDistribution());
       QStringList namesList(tr("Standard deviation"));
