@@ -33,7 +33,7 @@
 
 /*!
   \brief Constructor.
-  
+
   Creates new python command execution request.
 
   \param theInterp   python interpreter
@@ -42,9 +42,9 @@
   \param theSync     if \c true, the request is processed synchronously
 */
 PyConsole_ExecCommand::PyConsole_ExecCommand( PyInterp_Interp*        theInterp,
-                                              const QString&          theCommand,
-                                              QObject*                theListener,
-                                              bool                    theSync )
+    const QString&          theCommand,
+    QObject*                theListener,
+    bool                    theSync )
   : PyInterp_LockRequest( theInterp, theListener, theSync ),
     myCommand( theCommand ), myState( PyInterp_Event::ES_OK )
 {}
@@ -55,7 +55,8 @@ PyConsole_ExecCommand::PyConsole_ExecCommand( PyInterp_Interp*        theInterp,
 */
 void PyConsole_ExecCommand::execute()
 {
-  if ( myCommand != "" ) {
+  if ( myCommand != "" )
+  {
     int ret = getInterp()->run(myCommand.toUtf8());
     if ( ret < 0 )
       myState = PyInterp_Event::ES_ERROR;
@@ -93,10 +94,10 @@ QEvent* PyConsole_ExecCommand::createEvent()
   \param theSync if \c true the request is processed synchronously
 */
 PyConsole_CompletionCommand::PyConsole_CompletionCommand( PyInterp_Interp*   theInterp,
-                                                          const QString&     theInput,
-                                                          const QString&     theStartMatch,
-                                                          QObject*           theListener,
-                                                          bool               theSync )
+    const QString&     theInput,
+    const QString&     theStartMatch,
+    QObject*           theListener,
+    bool               theSync )
   : PyInterp_LockRequest( theInterp, theListener, theSync ),
     myDirArg( theInput ), myStartMatch( theStartMatch ), myStatus( false )
 {}
