@@ -38,8 +38,8 @@ PyInterp_Dispatcher* PyInterp_Dispatcher::Get()
   return myInstance;
 }
 
-PyInterp_Dispatcher::PyInterp_Dispatcher() 
-: QThread()
+PyInterp_Dispatcher::PyInterp_Dispatcher()
+  : QThread()
 {
 }
 
@@ -80,12 +80,13 @@ void PyInterp_Dispatcher::Exec( PyInterp_Request* theRequest )
     myQueueMutex.lock();
 
     myQueue.enqueue( theRequest );
-    if ( theRequest->listener() ) {
+    if ( theRequest->listener() )
+    {
       connect( theRequest->listener(), SIGNAL( destroyed( QObject* ) ),
                this, SLOT( objectDestroyed( QObject* ) ) );
     }
 
-    myQueueMutex.unlock();  
+    myQueueMutex.unlock();
 
     if ( !IsBusy() )
       start();
@@ -112,7 +113,7 @@ void PyInterp_Dispatcher::run()
 
     // prepare for removal of the first request in the queue
     myQueueMutex.lock();
-  
+
     // IMPORTANT: the first item could have been removed by objectDestroyed() --> we have to check it
     if ( myQueue.head() == aRequest ) // if it is still here --> remove it
       myQueue.dequeue();
