@@ -1,4 +1,4 @@
-// Copyright (C) 2007-2020  CEA/DEN, EDF R&D, OPEN CASCADE
+// Copyright (C) 2007-2022  CEA/DEN, EDF R&D, OPEN CASCADE
 //
 // Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
 // CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
@@ -56,16 +56,18 @@ static PyObject*
 PyStdOut_write(PyStdOut *self, PyObject *args)
 {
   char *c;
-  if (!PyArg_ParseTuple(args, "s",&c))
+  if (!PyArg_ParseTuple(args, "s", &c))
     return NULL;
-  if(self->_cb==NULL) {
+  if(self->_cb == NULL)
+  {
     if ( self->_iscerr )
       std::cerr << c ;
     else
       std::cout << c ;
   }
-  else {
-    self->_cb(self->_data,c);
+  else
+  {
+    self->_cb(self->_data, c);
   }
   Py_INCREF(Py_None);
   return Py_None;
@@ -78,19 +80,31 @@ PyStdOut_flush(PyStdOut * /*self*/, PyObject * /*args*/)
   return Py_None;
 }
 
-static PyMethodDef PyStdOut_methods[] = {
+static PyObject*
+PyStdOut_isatty(PyStdOut * /*self*/, PyObject */*args*/)
+{
+  return Py_False;
+}
+
+static PyMethodDef PyStdOut_methods[] =
+{
   {"write",  (PyCFunction)PyStdOut_write,  METH_VARARGS, PyDoc_STR("write(string) -> None")},
   {"flush",  (PyCFunction)PyStdOut_flush,  METH_NOARGS,  PyDoc_STR("flush() -> None")},
-  {NULL, (PyCFunction)NULL, 0, NULL}   /* sentinel */
+  {"isatty", (PyCFunction)PyStdOut_isatty, METH_NOARGS,  PyDoc_STR("isatty() -> bool")},
+  {NULL,     (PyCFunction)NULL,            0,            NULL}   /* sentinel */
 };
 
-static PyMemberDef PyStdOut_memberlist[] = {
-  {(char*)"softspace", T_INT,  offsetof(PyStdOut, softspace), 0,
-   (char*)"flag indicating that a space needs to be printed; used by print"},
+static PyMemberDef PyStdOut_memberlist[] =
+{
+  {
+    (char*)"softspace", T_INT,  offsetof(PyStdOut, softspace), 0,
+    (char*)"flag indicating that a space needs to be printed; used by print"
+  },
   {NULL, 0, 0, 0, NULL} /* Sentinel */
 };
 
-static PyTypeObject PyStdOut_Type = {
+static PyTypeObject PyStdOut_Type =
+{
   /* The ob_type field must be initialized in the module init function
    * to be portable to Windows without using C++. */
   PyVarObject_HEAD_INIT(NULL, 0)
@@ -150,6 +164,9 @@ static PyTypeObject PyStdOut_Type = {
   0,                            /*tp_print*/
 #endif
 #endif
+#if PY_VERSION_HEX >= 0x030C0000
+  0,                            /*tp_watched*/
+#endif
 };
 
 #define PyStdOut_Check(v)  ((v)->ob_type == &PyStdOut_Type)
@@ -178,7 +195,7 @@ char* PyInterp_Interp::_argv[] = {(char*)""};
   \brief Basic constructor.
 
   After construction the interpreter instance successor classes
-  must call virtual method initalize().
+  must call virtual method initialize().
 */
 PyInterp_Interp::PyInterp_Interp():
   _vout(0), _verr(0), _global_context(0), _local_context(0), _initialized(false)
@@ -196,7 +213,7 @@ PyInterp_Interp::~PyInterp_Interp()
 /*!
   \brief Initialize embedded interpreter.
 
-  This method shoud be called after construction of the interpreter.
+  This method should be called after construction of the interpreter.
   The method initialize() calls virtuals methods
   - initPython()  to initialize global Python interpreter
   - initContext() to initialize interpreter internal context
@@ -224,14 +241,15 @@ void PyInterp_Interp::initialize()
   // used to interpret & compile commands - this is really imported here
   // and only added again (with PyImport_AddModule) later on
   PyObjWrapper m(PyImport_ImportModule("codeop"));
-  if(!m) {
+  if(!m)
+  {
     PyErr_Print();
     return;
   }
 
   // Create python objects to capture stdout and stderr
-  _vout=(PyObject*)newPyStdOut( false ); // stdout
-  _verr=(PyObject*)newPyStdOut( true );  // stderr
+  _vout = (PyObject*)newPyStdOut( false ); // stdout
+  _verr = (PyObject*)newPyStdOut( true ); // stderr
 
   // All the initRun outputs are redirected to the standard output (console)
   initRun();
@@ -254,17 +272,27 @@ void PyInterp_Interp::destroy()
  */
 void PyInterp_Interp::initPython()
 {
-  if (!Py_IsInitialized()){
+  if (!Py_IsInitialized())
+  {
     // Python is not initialized
     wchar_t **changed_argv = new wchar_t*[_argc]; // Setting arguments
     for (int i = 0; i < _argc; i++)
     {
       changed_argv[i] = Py_DecodeLocale(_argv[i], NULL);
     }
-   
+
+#if PY_VERSION_HEX < 0x03080000
     Py_SetProgramName(changed_argv[0]);
     Py_Initialize(); // Initialize the interpreter
     PySys_SetArgv(_argc, changed_argv);
+#else
+    PyConfig config;
+    PyConfig_InitPythonConfig(&config);
+    PyStatus status = PyConfig_SetString(&config, &config.program_name, changed_argv[0]);
+    status = PyConfig_SetArgv(&config, _argc, changed_argv);
+    status = Py_InitializeFromConfig(&config);
+    PyConfig_Clear(&config);
+#endif
 
 #if PY_VERSION_HEX < 0x03070000
     PyEval_InitThreads(); // Create (and acquire) the Python global interpreter lock (GIL)
@@ -309,7 +337,8 @@ bool PyInterp_Interp::initRun()
 bool PyInterp_Interp::initContext()
 {
   PyObject *m = PyImport_AddModule("__main__");  // interpreter main module (module context)
-  if(!m){
+  if(!m)
+  {
     PyErr_Print();
     return false;
   }
@@ -334,7 +363,7 @@ void PyInterp_Interp::closeContext()
 /*!
   \brief Compile Python command and evaluate it in the
          python dictionary contexts if possible. This is not thread-safe.
-         This is the caller's responsability to make this thread-safe.
+         This is the caller's responsibility to make this thread-safe.
   \internal
   \param command Python command string
   \return -1 on fatal error, 1 if command is incomplete and 0
@@ -343,14 +372,16 @@ void PyInterp_Interp::closeContext()
 static int run_command(const char *command, PyObject * global_ctxt, PyObject * local_ctxt)
 {
   PyObject *m = PyImport_AddModule("codeop");
-  if(!m) {
+  if(!m)
+  {
     // Fatal error. No way to go on.
     PyErr_Print();
     return -1;
   }
 
-  PyObjWrapper v(PyObject_CallMethod(m,(char*)"compile_command",(char*)"s",command));
-  if(!v) {
+  PyObjWrapper v(PyObject_CallMethod(m, (char*)"compile_command", (char*)"s", command));
+  if(!v)
+  {
     // Error encountered. It should be SyntaxError,
     //so we don't write out traceback
     PyObjWrapper exception, value, tb;
@@ -359,13 +390,16 @@ static int run_command(const char *command, PyObject * global_ctxt, PyObject * l
     PyErr_Display(exception, value, NULL);
     return -1;
   }
-  else if (v == Py_None) {
+  else if (v == Py_None)
+  {
     // Incomplete text we return 1 : we need a complete text to execute
     return 1;
   }
-  else {
-    PyObjWrapper r(PyEval_EvalCode((PyObject *)(void *)v,global_ctxt, local_ctxt));
-    if(!r) {
+  else
+  {
+    PyObjWrapper r(PyEval_EvalCode((PyObject *)(void *)v, global_ctxt, local_ctxt));
+    if(!r)
+    {
       // Execution error. We return -1
       PyErr_Print();
       return -1;
@@ -375,14 +409,16 @@ static int run_command(const char *command, PyObject * global_ctxt, PyObject * l
   }
 }
 
-void replaceAll(std::string& str, const std::string& from, const std::string& to) {
-    if(from.empty())
-        return;
-    size_t start_pos = 0;
-    while((start_pos = str.find(from, start_pos)) != std::string::npos) {
-        str.replace(start_pos, from.length(), to);
-        start_pos += to.length(); // In case 'to' contains 'from', like replacing 'x' with 'yx'
-    }
+void replaceAll(std::string& str, const std::string& from, const std::string& to)
+{
+  if(from.empty())
+    return;
+  size_t start_pos = 0;
+  while((start_pos = str.find(from, start_pos)) != std::string::npos)
+  {
+    str.replace(start_pos, from.length(), to);
+    start_pos += to.length(); // In case 'to' contains 'from', like replacing 'x' with 'yx'
+  }
 }
 
 std::vector<std::string>
@@ -392,7 +428,8 @@ __split(const std::string& str, char delimiter)
   std::stringstream ss(str); // Turn the string into a stream.
   std::string tok;
 
-  while (getline(ss, tok, delimiter)) {
+  while (getline(ss, tok, delimiter))
+  {
     internal.push_back(tok);
   }
 
@@ -400,12 +437,13 @@ __split(const std::string& str, char delimiter)
 }
 
 std::string
-__join(const std::vector<std::string>& v, int begin=0, int end=-1)
+__join(const std::vector<std::string>& v, int begin = 0, int end = -1)
 {
   if (end == -1)
-    end = v.size();
+    end = (int)v.size(); //!< TODO: conversion from size_t to int
   std::stringstream ss;
-  for (int i = begin; i < end; ++i) {
+  for (int i = begin; i < end; ++i)
+  {
     if (i != begin)
       ss << ",";
     ss << v[i];
@@ -424,31 +462,35 @@ __getArgsList(std::string argsString)
   // We have to split argsString to obtain a 9 string elements list
   std::vector<std::string> x = __split(argsString, ',');
   bool containsList = (argsString.find('[') != std::string::npos);
-  if (containsList) {
+  if (containsList)
+  {
     std::vector<int> listBeginIndices, listEndIndices;
-    for (int pos = 0; pos < (int)x.size(); ++pos) {
+    for (int pos = 0; pos < (int)x.size(); ++pos)
+    {
       if (x[pos][0] == '[')
         listBeginIndices.push_back(pos);
-      else if (x[pos][x[pos].size()-1] == ']')
+      else if (x[pos][x[pos].size() - 1] == ']')
         listEndIndices.push_back(pos);
     }
     std::vector<std::string> extractedArgs;
     int start = 0;
-    for (int pos = 0; pos < (int)listBeginIndices.size(); ++pos) {
+    for (int pos = 0; pos < (int)listBeginIndices.size(); ++pos)
+    {
       int lbeg = listBeginIndices[pos];
       int lend = listEndIndices[pos];
       if (lbeg > start)
         for (int k = start; k < lbeg; ++k)
           extractedArgs.push_back(x[k]);
-      extractedArgs.push_back(__join(x, lbeg, lend+1));
-      start = lend+1;
+      extractedArgs.push_back(__join(x, lbeg, lend + 1));
+      start = lend + 1;
     }
     if (start < (int)x.size())
       for (int k = start; k < (int)x.size(); ++k)
         extractedArgs.push_back(x[k]);
     return extractedArgs;
   }
-  else {
+  else
+  {
     return x;
   }
 }
@@ -474,21 +516,24 @@ static int compile_command(const char *command, PyObject * global_ctxt, PyObject
 
   QRegularExpression rx("exec\\s*\\(.*open\\s*\\(\\s*(.*)\\s*\\)\\s*\\.\\s*read\\s*\\(\\)(\\s*,\\s*args\\s*=\\s*\\(.*\\))\\s*\\)");
   QRegularExpressionMatch match = rx.match(command);
-  if (match.hasMatch()) {
+  if (match.hasMatch())
+  {
     commandArgs = match.captured(2).remove(0, match.captured(2).indexOf("(")); // arguments of command
-    commandArgs.insert(commandArgs.indexOf('(')+1, match.captured(1).split(",")[0].trimmed() + ","); // prepend arguments list by the script file itself
+    commandArgs.insert(commandArgs.indexOf('(') + 1, match.captured(1).split(",")[0].trimmed() + ","); // prepend arguments list by the script file itself
     singleCommand = singleCommand.remove(match.capturedStart(2), match.captured(2).size()); // command for execution without arguments
   }
 
-  if (commandArgs.isEmpty()) {
+  if (commandArgs.isEmpty())
+  {
     return run_command(singleCommand.toStdString().c_str(), global_ctxt, local_ctxt);
   }
-  else {
+  else
+  {
     ///////////////std::vector<std::string> argList = __getArgsList(commandArgs);
     QString preCommandBegin = "import sys; save_argv = sys.argv; sys.argv=list(";
     QString preCommandEnd = ");";
     QString postCommand = ";sys.argv=save_argv";
-    QString completeCommand = preCommandBegin+commandArgs+preCommandEnd+singleCommand.trimmed()+postCommand;
+    QString completeCommand = preCommandBegin + commandArgs + preCommandEnd + singleCommand.trimmed() + postCommand;
     return run_command(completeCommand.toStdString().c_str(), global_ctxt, local_ctxt);
   }
 }
@@ -508,7 +553,7 @@ int PyInterp_Interp::run(const char *command)
 }
 
 /**
- * Called before a command is run (when calling run() method). Not thread-safe. Caller's responsability
+ * Called before a command is run (when calling run() method). Not thread-safe. Caller's responsibility
  * to acquire GIL if needed.
  */
 int PyInterp_Interp::beforeRun()
@@ -517,7 +562,7 @@ int PyInterp_Interp::beforeRun()
 }
 
 /**
- * Called after a command is run (when calling run() method). Not thread-safe. Caller's responsability
+ * Called after a command is run (when calling run() method). Not thread-safe. Caller's responsibility
  * to acquire GIL if needed.
  */
 int PyInterp_Interp::afterRun()
@@ -526,14 +571,15 @@ int PyInterp_Interp::afterRun()
 }
 
 /*!
-  \brief Run Python command (used internally). Not thread-safe. GIL acquisition is caller's responsability.
+  \brief Run Python command (used internally). Not thread-safe. GIL acquisition is caller's responsibility.
   \param command Python command
   \param addToHistory if \c true (default), the command is added to the commands history
   \return command status
 */
 int PyInterp_Interp::simpleRun(const char *command, const bool addToHistory)
 {
-  if( addToHistory && strcmp(command,"") != 0 ) {
+  if( addToHistory && strcmp(command, "") != 0 )
+  {
     _history.push_back(command);
     _ith = _history.end();
   }
@@ -546,14 +592,14 @@ int PyInterp_Interp::simpleRun(const char *command, const bool addToHistory)
   Py_INCREF(oldErr);
 
   // Redirect outputs to SALOME Python console before treatment
-  PySys_SetObject((char*)"stderr",_verr);
-  PySys_SetObject((char*)"stdout",_vout);
+  PySys_SetObject((char*)"stderr", _verr);
+  PySys_SetObject((char*)"stdout", _vout);
 
   int ier = compile_command(command, _global_context, _local_context);
 
   // Outputs are redirected to what they were before
-  PySys_SetObject((char*)"stdout",oldOut);
-  PySys_SetObject((char*)"stderr",oldErr);
+  PySys_SetObject((char*)"stdout", oldOut);
+  PySys_SetObject((char*)"stderr", oldErr);
 
   return ier;
 }
@@ -564,7 +610,8 @@ int PyInterp_Interp::simpleRun(const char *command, const bool addToHistory)
 */
 const char * PyInterp_Interp::getPrevious()
 {
-  if(_ith != _history.begin()){
+  if(_ith != _history.begin())
+  {
     _ith--;
     return (*_ith).c_str();
   }
@@ -578,7 +625,8 @@ const char * PyInterp_Interp::getPrevious()
 */
 const char * PyInterp_Interp::getNext()
 {
-  if(_ith != _history.end()){
+  if(_ith != _history.end())
+  {
     _ith++;
   }
   if (_ith == _history.end())
@@ -594,8 +642,8 @@ const char * PyInterp_Interp::getNext()
 */
 void PyInterp_Interp::setvoutcb(PyOutChanged* cb, void* data)
 {
-  ((PyStdOut*)_vout)->_cb=cb;
-  ((PyStdOut*)_vout)->_data=data;
+  ((PyStdOut*)_vout)->_cb = cb;
+  ((PyStdOut*)_vout)->_data = data;
 }
 
 /*!
@@ -605,8 +653,8 @@ void PyInterp_Interp::setvoutcb(PyOutChanged* cb, void* data)
 */
 void PyInterp_Interp::setverrcb(PyOutChanged* cb, void* data)
 {
-  ((PyStdOut*)_verr)->_cb=cb;
-  ((PyStdOut*)_verr)->_data=data;
+  ((PyStdOut*)_verr)->_cb = cb;
+  ((PyStdOut*)_verr)->_data = data;
 }
 
 /*!
