@@ -2,7 +2,7 @@
 /**
  *  @brief QWizard to choose a screening result
  *
- *  Copyright 2015-2023 EDF-Phimeca
+ *  Copyright 2015-2024 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -56,7 +56,7 @@ void ScreeningResultWizard::buildInterface()
   // choose InferenceAnalysis
   screeningResultsComboBox_ = new QComboBox;
   mainLayout->addWidget(new QLabel(tr("Morris analysis")), 0, 0);
-  mainLayout->addWidget(screeningResultsComboBox_ , 0, 1);
+  mainLayout->addWidget(screeningResultsComboBox_, 0, 1);
 
   for (UnsignedInteger i = 0; i < study_.getAnalyses().getSize(); ++i)
     if (study_.getAnalyses()[i].getImplementation()->getClassName() == "MorrisAnalysis")
@@ -88,7 +88,7 @@ void ScreeningResultWizard::buildInterface()
   mainLayout->addWidget(errorMessageLabel_, 3, 0, 1, 2);
 
   // connections
-  connect(variablesComboBox_, SIGNAL(currentIndexChanged(QString)), this, SLOT(updateTableModel(QString)));
+  connect(variablesComboBox_, SIGNAL(currentIndexChanged(int)), this, SLOT(updateTableModel(int)));
   connect(screeningResultsComboBox_, SIGNAL(currentIndexChanged(int)), this, SLOT(updateVariablesComboBox(int)));
 
   addPage(page);
@@ -116,7 +116,7 @@ void ScreeningResultWizard::updateVariablesComboBox(const int currentAnalysis)
 }
 
 
-void ScreeningResultWizard::updateTableModel(const QString& /*variableName*/)
+void ScreeningResultWizard::updateTableModel(const int index)
 {
   if (!screeningResultsComboBox_ || !variablesComboBox_ || !tableModel_)
     return;
@@ -126,7 +126,7 @@ void ScreeningResultWizard::updateTableModel(const QString& /*variableName*/)
   const int analysisIndex = screeningResultsComboBox_->itemData(screeningResultsComboBox_->currentIndex()).toInt();
   MorrisResult& result(dynamic_cast<MorrisAnalysis*>(study_.getAnalyses()[analysisIndex].getImplementation().get())->getResult());
 
-  tableModel_->updateData(result, variablesComboBox_->currentIndex());
+  tableModel_->updateData(result, index);
 }
 
 
