@@ -2,7 +2,7 @@
 /**
  *  @brief QItemDelegate to insert combobox in QTableView
  *
- *  Copyright 2015-2023 EDF-Phimeca
+ *  Copyright 2015-2024 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -107,7 +107,7 @@ QSize ComboBoxWithSeparatorDelegate::sizeHint(const QStyleOptionViewItem &option
 {
   QString type = index.data(Qt::AccessibleDescriptionRole).toString();
   if(type == QLatin1String("separator"))
-      return QSize(0, 10);
+    return QSize(0, 10);
   return QItemDelegate::sizeHint(option, index);
 }
 
@@ -115,9 +115,9 @@ QSize ComboBoxWithSeparatorDelegate::sizeHint(const QStyleOptionViewItem &option
 // -- ModelForComboBoxWithSeparator
 
 ModelForComboBoxWithSeparator::ModelForComboBoxWithSeparator(const QStringList &allItems,
-                                                             const QList<int> separatorIndex,
-                                                             const QStringList &separatorText,
-                                                             QWidget *parent)
+    const QList<int> separatorIndex,
+    const QStringList &separatorText,
+    QWidget *parent)
   : QStandardItemModel(parent)
 {
   for (int i = 0; i < allItems.size(); ++i)
@@ -188,8 +188,11 @@ QWidget *ComboBoxDelegate::createEditor(QWidget * parent, const QStyleOptionView
   // set Background color
   const QString defaultColor = index.model()->data(index, Qt::BackgroundRole).value<QColor>().name();
   editor->lineEdit()->setStyleSheet("QLineEdit {background: " + defaultColor + ";}");
-
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+  connect(editor, SIGNAL(textActivated(QString)), this, SLOT(emitCommitData()));
+#else
   connect(editor, SIGNAL(activated(QString)), this, SLOT(emitCommitData()));
+#endif
   return editor;
 }
 
