@@ -2,7 +2,7 @@
 /**
  *  @brief Generic data table
  *
- *  Copyright 2015-2023 EDF-Phimeca
+ *  Copyright 2015-2024 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -104,8 +104,8 @@ QString CopyableTableView::getFormattedText() const
 
   for (int i = 0; i < list.size(); ++i)
   {
-    QVariant data = model()->data(previous);
-    QString text = data.toString();
+    QVariant modelData = model()->data(previous);
+    QString text = modelData.toString();
     result.append(text);
 
     QModelIndex index = list.at(i);
