@@ -2,7 +2,7 @@
 /**
  *  @brief QDialog to define values
  *
- *  Copyright 2015-2023 EDF-Phimeca
+ *  Copyright 2015-2024 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -104,7 +104,7 @@ void EditValuesWizard::buildInterface()
   proxy_->sort(0);
   valueTable_->horizontalHeader()->setStretchLastSection(true);
   valueTable_->verticalHeader()->hide();
-  connect(valueTable_->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)), this, SLOT(checkButtons()));
+  connect(valueTable_->selectionModel(), SIGNAL(selectionChanged(QItemSelection, QItemSelection)), this, SLOT(checkButtons()));
 
   QVBoxLayout * optionLayout = new QVBoxLayout;
 
@@ -154,7 +154,7 @@ void EditValuesWizard::addValue()
     Point newpoint(model_->columnCount());
     for (int i = 0; i < model_->columnCount(); ++i)
     {
-      const QModelIndex greaterValueIndex(proxy_->mapToSource(proxy_->index(proxy_->rowCount()-1, i)));
+      const QModelIndex greaterValueIndex(proxy_->mapToSource(proxy_->index(proxy_->rowCount() - 1, i)));
       newpoint[i] = model_->data(greaterValueIndex, Qt::UserRole).toDouble() + 1;
     }
     sample.add(newpoint);
@@ -177,14 +177,15 @@ void EditValuesWizard::importSample()
   ImportedDistributionPage * page = new ImportedDistributionPage;
   importWizard->addPage(page);
 
-  if (importWizard->exec()) {
+  if (importWizard->exec())
+  {
     Sample newSample(page->getData().getSize(), 0);
     // Columns from imported sample
     newSample.stack(page->getData().getMarginal(Description(1, tr("Value").toStdString())));
     const Description columnNames = page->getData().getDescription();
     const Description::const_iterator it = std::find(columnNames.begin(),
-                                                     columnNames.end(),
-                                                     tr("Weight").toStdString());
+                                           columnNames.end(),
+                                           tr("Weight").toStdString());
     // Widget has been used to specify probabilities
     if (it != columnNames.end())
       newSample.stack(page->getData().getMarginal(Description(1, tr("Weight").toStdString())));
@@ -222,7 +223,6 @@ void EditValuesWizard::removeSelectedValues()
   Sample sample(model_->getSample());
   foreach (int row, selectedRow)
   {
-    Point point(sample[row]);
     sample.erase(row);
   }
   model_->updateData(sample);
@@ -273,7 +273,7 @@ UserDefinedWizard::UserDefinedWizard(const Distribution::PointWithDescriptionCol
   }
   Description description(2);
   description[0] = tr("Value").toStdString();
-  description[1] = tr("Weight").toStdString();
+  description[1] = tr("Weight (>0, optional)").toStdString();
   sample.setDescription(description);
   model_ = new WeightTableModel(sample, this);
   connect(model_, SIGNAL(dataChanged(QModelIndex, QModelIndex)), errorMessageLabel_, SLOT(reset()));
@@ -285,19 +285,33 @@ UserDefinedWizard::UserDefinedWizard(const Distribution::PointWithDescriptionCol
 
 void UserDefinedWizard::addValue()
 {
-  Point newpoint(model_->columnCount());
-  const QModelIndex greaterValueIndex(proxy_->mapToSource(proxy_->index(proxy_->rowCount()-1, 0)));
-  newpoint[0] = model_->data(greaterValueIndex, Qt::UserRole).toDouble() + 1;
-
-  Sample sample(model_->getSample());
-  Point proba(sample.getMarginal(1).asPoint());
-  // if sum < 1 : p = 1 - sum
-  // if sum >= 1 : p = 0
-  newpoint[1] = 1.0 - std::min(std::accumulate(proba.begin(), proba.end(), 0.0), 1.0);
-
-  sample.add(newpoint);
-  model_->updateData(sample);
-
+  if (proxy_->rowCount() && model_->columnCount())
+  {
+    Point newpoint(model_->columnCount());
+    const QModelIndex greaterValueIndex(proxy_->mapToSource(proxy_->index(proxy_->rowCount() - 1, 0)));
+    newpoint[0] = model_->data(greaterValueIndex, Qt::UserRole).toDouble() + 1;
+    Sample sample(model_->getSample());
+    Point proba(sample.getMarginal(1).asPoint());
+    if (proba.getDimension())
+      newpoint[1] = proba[proba.getDimension() - 1];
+    else
+      newpoint[1] = 1;
+    sample.add(newpoint);
+    model_->updateData(sample);
+  }
+  else // Table has been emptied
+  {
+    Point point(2);
+    point[0] = 0;
+    point[1] = 1;
+    Sample sample(0, 2);
+    sample.add(point);
+    Description description(2);
+    description[0] = tr("Value").toStdString();
+    description[1] = tr("Weight (>0, optional)").toStdString();
+    sample.setDescription(description);
+    model_->updateData(sample);
+  }
   check();
 }
 
@@ -330,23 +344,26 @@ ImportedDistributionPage::ImportedDistributionPage(QWidget *parent)
   errorMessageLabel_ = new TemporaryLabel;
   pageLayout->addWidget(errorMessageLabel_);
 
-  connect(sampleWidget_, &ImportSampleWidget::updateTableRequested, [=](const QString & fileName) {
+  connect(sampleWidget_, &ImportSampleWidget::updateTableRequested, [ = ](const QString & fileName)
+  {
     errorMessageLabel_->setText("");
     Sample sample = Tools::ImportSample(fileName.toStdString());
     Indices allIndices = Indices(sample.getDimension());
     allIndices.fill(0, 1);
-    Description description(2);
-    description[0] = tr("Value").toStdString();
-    description[1] = tr("Weight").toStdString();
-    sampleWidget_->updateWidgets(sample, sample.getDescription(), allIndices, description);});
+    Description description;
+    description.add(tr("Value").toStdString());
+    if (sample.getDimension() > 1)
+      description.add(tr("Weight").toStdString());
+    sampleWidget_->updateWidgets(sample, sample.getDescription(), allIndices, description);
+  });
 }
 
 bool ImportedDistributionPage::validatePage()
 {
   const Description desc = getData().getDescription();
-  for (UnsignedInteger i=0; i<desc.getSize()-1; ++i)
+  for (UnsignedInteger i = 0; i < desc.getSize() - 1; ++i)
   {
-    for (UnsignedInteger j=i+1; j<desc.getSize(); ++j)
+    for (UnsignedInteger j = i + 1; j < desc.getSize(); ++j)
     {
       if (desc[i] == desc[j] && desc[i] != "")
       {
