@@ -60,8 +60,8 @@ ott.assert_almost_equal(mean, [0, 0], 0.3, 0.3)
 ott.assert_almost_equal(stddev, [math.sqrt(3.0), 1.415], 0.3, 0.3)
 
 # post-processing
-code = 'import random\ndef _exec2(Y0, Y1):\n    A=r"U\\U-N\\N-u\\u-x\\x"\n    z = random.random()\n'
-code += '    Y2 = Y0+3*Y1\n    Y3 = Y2+3*Y1\n    return Y2, Y3\n'
+code = 'import random\ndef _exec2(Y0, Y1):\n    A=r\\"U\\U-N\\N-u\\u-x\\x\\"\n    z = random.random()\n'
+code += "    Y2 = Y0+3*Y1\n    Y3 = Y2+3*Y1\n    return Y2, Y3\n"
 step.setCode(code)
 model = persalys.CouplingPhysicalModel("A", [step])
 f = model.getFunction()
@@ -90,7 +90,7 @@ f = model.getFunction()
 try:
     f(x)
     print("FAIL")
-except Exception:
+except RuntimeError:
     print("OK")
 
 try:
@@ -274,7 +274,7 @@ f = persalys.PhysicalModel(model).getFunction()
 for i in range(5):
     y = f(x)
 print(y)
-print("n calls=", f.getCallsNumber())
+print("n calls=", f.getEvaluationCallsNumber())
 
 ott.assert_almost_equal(y, [6.0, 7.0])
 
@@ -365,29 +365,23 @@ ott.assert_almost_equal(y, [6.0, 7.0, 39.0, 146.0])
 
 # test environment override
 with open("program4.py", "w") as f:
-    f.write('import persalys as prs\n')
+    f.write("import persalys as prs\n")
 
 resource_file = persalys.CouplingResourceFile("program4.py")
 step5 = persalys.CouplingStep(sys.executable + " program4.py", [], [resource_file], [])
-step5.setEnvironment(['PYTHONPATH', 'PYTHONHOME'], ['', ''])
+step5.setEnvironment(["PYTHONPATH", "PYTHONHOME"], ["", ""])
 model2 = persalys.CouplingPhysicalModel("envTest", [step1, step5])
 x = [1.0, 2.0, 3.0]
 f = model2.getFunction()
 try:
     y = f(x)
     # oddly conda still runs without PYTHONPATH/PYTHONHOME
-    if 'conda' in sys.version:
-        raise ValueError('oh wow')
+    if "conda" in sys.version:
+        raise ValueError("oh wow")
     print("FAIL")
 except Exception:
     print("OK")
 
-# clean environment
-step5.setEnvironment(ot.Description(), ot.Description())
-model2 = persalys.CouplingPhysicalModel("envTest", [step1, step5])
-f = model2.getFunction()
-y = f(x)
-
 # cleanup
 os.remove("input1.txt.in")
 os.remove("program1.py")
